#
# PySNMP MIB module CPQHOST-MIB (http://pysnmp.sf.net)
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( sysName, ) = mibBuilder.importSymbols("SNMPv2-MIB", "sysName")
( Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, MibIdentifier, IpAddress, TimeTicks, Counter64, Unsigned32, enterprises, iso, Gauge32, NotificationType, ModuleIdentity, ObjectIdentity, Bits, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "NotificationType", "MibIdentifier", "IpAddress", "TimeTicks", "Counter64", "Unsigned32", "enterprises", "iso", "Gauge32", "NotificationType", "ModuleIdentity", "ObjectIdentity", "Bits", "Counter32")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
compaq = MibIdentifier((1, 3, 6, 1, 4, 1, 232))
cpqHostOs = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11))
cpqHoMibRev = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 1))
cpqHoComponent = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2))
cpqHoInterface = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 1))
cpqHoInfo = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 2))
cpqHoUtil = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 3))
cpqHoFileSys = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 4))
cpqHoIfPhysMap = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 5))
cpqHoSWRunning = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 6))
cpqHoSwVer = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 7))
cpqHoGeneric = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 8))
cpqHoSwPerf = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 9))
cpqHoSystemStatus = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 10))
cpqHoTrapInfo = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 11))
cpqHoClients = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 12))
cpqHoMemory = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 13))
cpqHoFwVer = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 14))
cpqHoHWInfo = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 15))
cpqPwrThreshold = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 16))
cpqHoOsCommon = MibIdentifier((1, 3, 6, 1, 4, 1, 232, 11, 2, 1, 4))
cpqHoMibRevMajor = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
cpqHoMibRevMinor = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
cpqHoMibCondition = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 1, 3), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4,)).clone(namedValues=NamedValues(("unknown", 1), ("ok", 2), ("degraded", 3), ("failed", 4),))).setMaxAccess("readonly")
cpqHoOsCommonPollFreq = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 1, 4, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readwrite")
cpqHoOsCommonModuleTable = MibTable((1, 3, 6, 1, 4, 1, 232, 11, 2, 1, 4, 2), )
cpqHoOsCommonModuleEntry = MibTableRow((1, 3, 6, 1, 4, 1, 232, 11, 2, 1, 4, 2, 1), ).setIndexNames((0, "CPQHOST-MIB", "cpqHoOsCommonModuleIndex"))
cpqHoOsCommonModuleIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 1, 4, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readonly")
cpqHoOsCommonModuleName = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 1, 4, 2, 1, 2), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoOsCommonModuleVersion = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 1, 4, 2, 1, 3), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,5))).setMaxAccess("readonly")
cpqHoOsCommonModuleDate = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 1, 4, 2, 1, 4), OctetString().subtype(subtypeSpec=ValueSizeConstraint(7,7)).setFixedLength(7)).setMaxAccess("readonly")
cpqHoOsCommonModulePurpose = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 1, 4, 2, 1, 5), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoName = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 2, 1), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoVersion = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 2, 2), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoDesc = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 2, 3), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoOsType = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 2, 4), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54,)).clone(namedValues=NamedValues(("other", 1), ("netware", 2), ("windowsnt", 3), ("sco-unix", 4), ("unixware", 5), ("os-2", 6), ("ms-dos", 7), ("dos-windows", 8), ("windows95", 9), ("windows98", 10), ("open-vms", 11), ("nsk", 12), ("windowsCE", 13), ("linux", 14), ("windows2000", 15), ("tru64UNIX", 16), ("windows2003", 17), ("windows2003-x64", 18), ("solaris", 19), ("windows2003-ia64", 20), ("windows2008", 21), ("windows2008-x64", 22), ("windows2008-ia64", 23), ("vmware-esx", 24), ("vmware-esxi", 25), ("windows2012", 26), ("windows7", 27), ("windows7-x64", 28), ("windows8", 29), ("windows8-x64", 30), ("windows81", 31), ("windows81-x64", 32), ("windowsxp", 33), ("windowsxp-x64", 34), ("windowsvista", 35), ("windowsvista-x64", 36), ("windows2008-r2", 37), ("windows2012-r2", 38), ("rhel", 39), ("rhel-64", 40), ("solaris-64", 41), ("sles", 42), ("sles-64", 43), ("ubuntu", 44), ("ubuntu-64", 45), ("debian", 46), ("debian-64", 47), ("linux-64-bit", 48), ("other-64-bit", 49), ("centos-32bit", 50), ("centos-64bit", 51), ("oracle-linux32", 52), ("oracle-linux64", 53), ("apple-osx", 54),))).setMaxAccess("readonly")
cpqHoTelnet = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 2, 5), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3,)).clone(namedValues=NamedValues(("other", 1), ("available", 2), ("notavailable", 3),))).setMaxAccess("readonly")
cpqHoSystemRole = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 2, 6), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,64))).setMaxAccess("readwrite")
cpqHoSystemRoleDetail = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 2, 7), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,512))).setMaxAccess("readwrite")
cpqHoCrashDumpState = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 2, 8), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4,)).clone(namedValues=NamedValues(("completememorydump", 1), ("kernelmemorydump", 2), ("smallmemorydump", 3), ("none", 4),))).setMaxAccess("readonly")
cpqHoCrashDumpCondition = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 2, 9), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4,)).clone(namedValues=NamedValues(("other", 1), ("ok", 2), ("degraded", 3), ("failed", 4),))).setMaxAccess("readonly")
cpqHoCrashDumpMonitoring = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 2, 10), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2,)).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2),))).setMaxAccess("readwrite")
cpqHoMaxLogicalCPUSupported = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 2, 11), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
cpqHoSystemName = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 2, 12), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHosysDescr = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 2, 13), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoCpuUtilTable = MibTable((1, 3, 6, 1, 4, 1, 232, 11, 2, 3, 1), )
cpqHoCpuUtilEntry = MibTableRow((1, 3, 6, 1, 4, 1, 232, 11, 2, 3, 1, 1), ).setIndexNames((0, "CPQHOST-MIB", "cpqHoCpuUtilUnitIndex"))
cpqHoCpuUtilUnitIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 3, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
cpqHoCpuUtilMin = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 3, 1, 1, 2), Integer32()).setMaxAccess("readonly")
cpqHoCpuUtilFiveMin = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 3, 1, 1, 3), Integer32()).setMaxAccess("readonly")
cpqHoCpuUtilThirtyMin = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 3, 1, 1, 4), Integer32()).setMaxAccess("readonly")
cpqHoCpuUtilHour = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 3, 1, 1, 5), Integer32()).setMaxAccess("readonly")
cpqHoCpuUtilHwLocation = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 3, 1, 1, 6), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoFileSysTable = MibTable((1, 3, 6, 1, 4, 1, 232, 11, 2, 4, 1), )
cpqHoFileSysEntry = MibTableRow((1, 3, 6, 1, 4, 1, 232, 11, 2, 4, 1, 1), ).setIndexNames((0, "CPQHOST-MIB", "cpqHoFileSysIndex"))
cpqHoFileSysIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 4, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
cpqHoFileSysDesc = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 4, 1, 1, 2), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoFileSysSpaceTotal = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 4, 1, 1, 3), Integer32()).setMaxAccess("readonly")
cpqHoFileSysSpaceUsed = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 4, 1, 1, 4), Integer32()).setMaxAccess("readonly")
cpqHoFileSysPercentSpaceUsed = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 4, 1, 1, 5), Integer32()).setMaxAccess("readonly")
cpqHoFileSysAllocUnitsTotal = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 4, 1, 1, 6), Integer32()).setMaxAccess("readonly")
cpqHoFileSysAllocUnitsUsed = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 4, 1, 1, 7), Integer32()).setMaxAccess("readonly")
cpqHoFileSysStatus = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 4, 1, 1, 8), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4,)).clone(namedValues=NamedValues(("unknown", 1), ("ok", 2), ("degraded", 3), ("failed", 4),))).setMaxAccess("readonly")
cpqHoFileSysShortDesc = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 4, 1, 1, 9), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoFileSysCondition = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 4, 2), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4,)).clone(namedValues=NamedValues(("unknown", 1), ("ok", 2), ("degraded", 3), ("failed", 4),))).setMaxAccess("readonly")
cpqHoIfPhysMapTable = MibTable((1, 3, 6, 1, 4, 1, 232, 11, 2, 5, 1), )
cpqHoIfPhysMapEntry = MibTableRow((1, 3, 6, 1, 4, 1, 232, 11, 2, 5, 1, 1), ).setIndexNames((0, "CPQHOST-MIB", "cpqHoIfPhysMapIndex"))
cpqHoIfPhysMapIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 5, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
cpqHoIfPhysMapSlot = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 5, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readonly")
cpqHoIfPhysMapIoBaseAddr = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 5, 1, 1, 3), Integer32()).setMaxAccess("readonly")
cpqHoIfPhysMapIrq = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 5, 1, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readonly")
cpqHoIfPhysMapDma = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 5, 1, 1, 5), Integer32()).setMaxAccess("readonly")
cpqHoIfPhysMapMemBaseAddr = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 5, 1, 1, 6), Integer32()).setMaxAccess("readonly")
cpqHoIfPhysMapPort = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 5, 1, 1, 7), Integer32()).setMaxAccess("readonly")
cpqHoIfPhysMapDuplexState = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 5, 1, 1, 8), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3,)).clone(namedValues=NamedValues(("other", 1), ("half", 2), ("full", 3),))).setMaxAccess("readonly")
cpqHoIfPhysMapCondition = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 5, 1, 1, 9), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4,)).clone(namedValues=NamedValues(("other", 1), ("ok", 2), ("degraded", 3), ("failed", 4),))).setMaxAccess("readonly")
cpqHoIfPhysMapOverallCondition = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 5, 2), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4,)).clone(namedValues=NamedValues(("other", 1), ("ok", 2), ("degraded", 3), ("failed", 4),))).setMaxAccess("readonly")
cpqHoSWRunningTable = MibTable((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1), )
cpqHoSWRunningEntry = MibTableRow((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1), ).setIndexNames((0, "CPQHOST-MIB", "cpqHoSWRunningIndex"))
cpqHoSWRunningIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
cpqHoSWRunningName = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 2), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoSWRunningDesc = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 3), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoSWRunningVersion = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 4), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoSWRunningDate = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 5), OctetString().subtype(subtypeSpec=ValueSizeConstraint(7,7)).setFixedLength(7)).setMaxAccess("readonly")
cpqHoSWRunningMonitor = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 6), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8,)).clone(namedValues=NamedValues(("other", 1), ("start", 2), ("stop", 3), ("startAndStop", 4), ("count", 5), ("startAndCount", 6), ("countAndStop", 7), ("startCountAndStop", 8),))).setMaxAccess("readonly")
cpqHoSWRunningState = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 7), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3,)).clone(namedValues=NamedValues(("other", 1), ("started", 2), ("stopped", 3),))).setMaxAccess("readonly")
cpqHoSWRunningCount = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
cpqHoSWRunningCountMin = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readwrite")
cpqHoSWRunningCountMax = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 10), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readwrite")
cpqHoSWRunningEventTime = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 11), OctetString().subtype(subtypeSpec=ValueSizeConstraint(7,7)).setFixedLength(7)).setMaxAccess("readonly")
cpqHoSWRunningStatus = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 12), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5, 6, 7,)).clone(namedValues=NamedValues(("unknown", 1), ("normal", 2), ("warning", 3), ("minor", 4), ("major", 5), ("critical", 6), ("disabled", 7),))).setMaxAccess("readonly")
cpqHoSWRunningConfigStatus = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 13), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5,)).clone(namedValues=NamedValues(("unknown", 1), ("starting", 2), ("initialized", 3), ("configured", 4), ("operational", 5),))).setMaxAccess("readonly")
cpqHoSWRunningIdentifier = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 14), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoSWRunningRedundancyMode = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 1, 1, 15), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4,)).clone(namedValues=NamedValues(("unknown", 1), ("master", 2), ("backup", 3), ("slave", 4),))).setMaxAccess("readonly")
cpqHoSwRunningTrapDesc = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 6, 2), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoSwVerNextIndex = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 7, 1), Integer32()).setMaxAccess("readonly")
cpqHoSwVerTable = MibTable((1, 3, 6, 1, 4, 1, 232, 11, 2, 7, 2), )
cpqHoSwVerEntry = MibTableRow((1, 3, 6, 1, 4, 1, 232, 11, 2, 7, 2, 1), ).setIndexNames((0, "CPQHOST-MIB", "cpqHoSwVerIndex"))
cpqHoSwVerIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 7, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
cpqHoSwVerStatus = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 7, 2, 1, 2), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3,)).clone(namedValues=NamedValues(("other", 1), ("loaded", 2), ("notloaded", 3),))).setMaxAccess("readonly")
cpqHoSwVerType = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 7, 2, 1, 3), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5, 6,)).clone(namedValues=NamedValues(("other", 1), ("driver", 2), ("agent", 3), ("sysutil", 4), ("application", 5), ("keyfile", 6),))).setMaxAccess("readwrite")
cpqHoSwVerName = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 7, 2, 1, 4), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,127))).setMaxAccess("readwrite")
cpqHoSwVerDescription = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 7, 2, 1, 5), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,127))).setMaxAccess("readwrite")
cpqHoSwVerDate = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 7, 2, 1, 6), OctetString().subtype(subtypeSpec=ValueSizeConstraint(7,7)).setFixedLength(7)).setMaxAccess("readonly")
cpqHoSwVerLocation = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 7, 2, 1, 7), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readwrite")
cpqHoSwVerVersion = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 7, 2, 1, 8), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,50))).setMaxAccess("readonly")
cpqHoSwVerVersionBinary = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 7, 2, 1, 9), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,50))).setMaxAccess("readonly")
cpqHoSwVerAgentsVer = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 7, 3), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,50))).setMaxAccess("readonly")
cpqHoGenericData = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 8, 1), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,254))).setMaxAccess("readwrite")
cpqHoCriticalSoftwareUpdateData = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 8, 2), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,512))).setMaxAccess("readwrite")
cpqHoSwPerfAppErrorDesc = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 9, 1), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,254))).setMaxAccess("readonly")
cpqHoMibStatusArray = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 10, 1), OctetString().subtype(subtypeSpec=ValueSizeConstraint(4,256))).setMaxAccess("readonly")
cpqHoConfigChangedDate = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 10, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(7,7)).setFixedLength(7)).setMaxAccess("readonly")
cpqHoGUID = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 10, 3), OctetString().subtype(subtypeSpec=ValueSizeConstraint(16,17))).setMaxAccess("readwrite")
cpqHoCodeServer = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 10, 4), Integer32()).setMaxAccess("readonly")
cpqHoWebMgmtPort = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 10, 5), Integer32()).setMaxAccess("readonly")
cpqHoGUIDCanonical = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 10, 6), OctetString().subtype(subtypeSpec=ValueSizeConstraint(32,36))).setMaxAccess("readwrite")
cpqHoMibHealthStatusArray = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 10, 7), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,256))).setMaxAccess("readonly")
cpqHoTrapFlags = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 11, 1), Integer32()).setMaxAccess("readonly")
cpqHoClientLastModified = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 12, 1), OctetString().subtype(subtypeSpec=ValueSizeConstraint(7,7)).setFixedLength(7)).setMaxAccess("readonly")
cpqHoClientDelete = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 12, 2), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,15))).setMaxAccess("readwrite")
cpqHoClientTable = MibTable((1, 3, 6, 1, 4, 1, 232, 11, 2, 12, 3), )
cpqHoClientEntry = MibTableRow((1, 3, 6, 1, 4, 1, 232, 11, 2, 12, 3, 1), ).setIndexNames((0, "CPQHOST-MIB", "cpqHoClientIndex"))
cpqHoClientIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 12, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
cpqHoClientName = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 12, 3, 1, 2), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,15))).setMaxAccess("readonly")
cpqHoClientIpxAddress = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 12, 3, 1, 3), OctetString().subtype(subtypeSpec=ValueSizeConstraint(20,20)).setFixedLength(20)).setMaxAccess("readonly")
cpqHoClientIpAddress = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 12, 3, 1, 4), IpAddress()).setMaxAccess("readonly")
cpqHoClientCommunity = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 12, 3, 1, 5), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,48))).setMaxAccess("readonly")
cpqHoClientID = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 12, 3, 1, 6), OctetString().subtype(subtypeSpec=ValueSizeConstraint(16,16)).setFixedLength(16)).setMaxAccess("readonly")
cpqHoPhysicalMemorySize = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 13, 1), Integer32()).setMaxAccess("readonly")
cpqHoPhysicalMemoryFree = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 13, 2), Integer32()).setMaxAccess("readonly")
cpqHoPagingMemorySize = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 13, 3), Integer32()).setMaxAccess("readonly")
cpqHoPagingMemoryFree = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 13, 4), Integer32()).setMaxAccess("readonly")
cpqHoBootPagingFileSize = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 13, 5), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,10))).setMaxAccess("readonly")
cpqHoBootPagingFileMinimumSize = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 13, 6), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,10))).setMaxAccess("readonly")
cpqHoBootPagingFileVolumeFreeSpace = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 13, 7), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,10))).setMaxAccess("readonly")
cpqHoFwVerTable = MibTable((1, 3, 6, 1, 4, 1, 232, 11, 2, 14, 1), )
cpqHoFwVerEntry = MibTableRow((1, 3, 6, 1, 4, 1, 232, 11, 2, 14, 1, 1), ).setIndexNames((0, "CPQHOST-MIB", "cpqHoFwVerIndex"))
cpqHoFwVerIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 14, 1, 1, 1), Integer32()).setMaxAccess("readonly")
cpqHoFwVerCategory = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 14, 1, 1, 2), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5,)).clone(namedValues=NamedValues(("other", 1), ("storage", 2), ("nic", 3), ("rib", 4), ("system", 5),))).setMaxAccess("readonly")
cpqHoFwVerDeviceType = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 14, 1, 1, 3), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31,)).clone(namedValues=NamedValues(("other", 1), ("internalArrayController", 2), ("fibreArrayController", 3), ("scsiController", 4), ("fibreChannelTapeController", 5), ("modularDataRouter", 6), ("ideCdRomDrive", 7), ("ideDiskDrive", 8), ("scsiCdRom-ScsiAttached", 9), ("scsiDiskDrive-ScsiAttached", 10), ("scsiTapeDrive-ScsiAttached", 11), ("scsiTapeLibrary-ScsiAttached", 12), ("scsiDiskDrive-ArrayAttached", 13), ("scsiTapeDrive-ArrayAttached", 14), ("scsiTapeLibrary-ArrayAttached", 15), ("scsiDiskDrive-FibreAttached", 16), ("scsiTapeDrive-FibreAttached", 17), ("scsiTapeLibrary-FibreAttached", 18), ("scsiEnclosureBackplaneRom-ScsiAttached", 19), ("scsiEnclosureBackplaneRom-ArrayAttached", 20), ("scsiEnclosureBackplaneRom-FibreAttached", 21), ("scsiEnclosureBackplaneRom-ra4x00", 22), ("systemRom", 23), ("networkInterfaceController", 24), ("remoteInsightBoard", 25), ("sasDiskDrive-SasAttached", 26), ("sataDiskDrive-SataAttached", 27), ("usbController", 28), ("sasControllerAdapter", 29), ("sataControllerAdapter", 30), ("systemDevice", 31),))).setMaxAccess("readonly")
cpqHoFwVerDisplayName = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 14, 1, 1, 4), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,127))).setMaxAccess("readonly")
cpqHoFwVerVersion = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 14, 1, 1, 5), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,31))).setMaxAccess("readonly")
cpqHoFwVerLocation = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 14, 1, 1, 6), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoFwVerXmlString = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 14, 1, 1, 7), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
cpqHoFwVerKeyString = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 14, 1, 1, 8), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,127))).setMaxAccess("readonly")
cpqHoFwVerUpdateMethod = MibTableColumn((1, 3, 6, 1, 4, 1, 232, 11, 2, 14, 1, 1, 9), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4,)).clone(namedValues=NamedValues(("other", 1), ("noUpdate", 2), ("softwareflash", 3), ("replacePhysicalRom", 4),))).setMaxAccess("readonly")
cpqHoHWInfoPlatform = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 15, 1), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5,)).clone(namedValues=NamedValues(("unknown", 1), ("cellular", 2), ("foundation", 3), ("virtualMachine", 4), ("serverBlade", 5),))).setMaxAccess("readonly")
cpqPwrWarnType = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 16, 1), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,254))).setMaxAccess("readwrite")
cpqPwrWarnThreshold = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 16, 2), Integer32()).setMaxAccess("readwrite")
cpqPwrWarnDuration = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 16, 3), Integer32()).setMaxAccess("readwrite")
cpqSerialNum = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 16, 4), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,254))).setMaxAccess("readwrite")
cpqServerUUID = MibScalar((1, 3, 6, 1, 4, 1, 232, 11, 2, 16, 5), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,254))).setMaxAccess("readwrite")
cpqHoGenericTrap = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11001)).setObjects(*(("CPQHOST-MIB", "cpqHoGenericData"),))
cpqHoAppErrorTrap = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11002)).setObjects(*(("CPQHOST-MIB", "cpqHoSwPerfAppErrorDesc"),))
cpqHo2GenericTrap = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11003)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoGenericData"),))
cpqHo2AppErrorTrap = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11004)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoSwPerfAppErrorDesc"),))
cpqHo2NicStatusOk = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11005)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoIfPhysMapSlot"),))
cpqHo2NicStatusFailed = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11006)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoIfPhysMapSlot"),))
cpqHo2NicSwitchoverOccurred = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11007)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoIfPhysMapSlot"), ("CPQHOST-MIB", "cpqHoIfPhysMapSlot"),))
cpqHo2NicStatusOk2 = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11008)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoIfPhysMapSlot"), ("CPQHOST-MIB", "cpqHoIfPhysMapPort"),))
cpqHo2NicStatusFailed2 = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11009)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoIfPhysMapSlot"), ("CPQHOST-MIB", "cpqHoIfPhysMapPort"),))
cpqHo2NicSwitchoverOccurred2 = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11010)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoIfPhysMapSlot"), ("CPQHOST-MIB", "cpqHoIfPhysMapPort"), ("CPQHOST-MIB", "cpqHoIfPhysMapSlot"), ("CPQHOST-MIB", "cpqHoIfPhysMapPort"),))
cpqHoProcessEventTrap = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11011)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoSwRunningTrapDesc"),))
cpqHoProcessCountWarning = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11012)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoSWRunningName"), ("CPQHOST-MIB", "cpqHoSWRunningCount"), ("CPQHOST-MIB", "cpqHoSWRunningCountMin"), ("CPQHOST-MIB", "cpqHoSWRunningCountMax"), ("CPQHOST-MIB", "cpqHoSWRunningEventTime"),))
cpqHoProcessCountNormal = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11013)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoSWRunningName"), ("CPQHOST-MIB", "cpqHoSWRunningCount"), ("CPQHOST-MIB", "cpqHoSWRunningCountMin"), ("CPQHOST-MIB", "cpqHoSWRunningCountMax"), ("CPQHOST-MIB", "cpqHoSWRunningEventTime"),))
cpqHoCriticalSoftwareUpdateTrap = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11014)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoCriticalSoftwareUpdateData"),))
cpqHoCrashDumpNotEnabledTrap = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11015)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoCrashDumpState"),))
cpqHoBootPagingFileTooSmallTrap = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11016)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoCrashDumpState"), ("CPQHOST-MIB", "cpqHoBootPagingFileSize"), ("CPQHOST-MIB", "cpqHoBootPagingFileMinimumSize"),))
cpqHoSWRunningStatusChangeTrap = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11017)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoSWRunningName"), ("CPQHOST-MIB", "cpqHoSWRunningDesc"), ("CPQHOST-MIB", "cpqHoSwRunningTrapDesc"), ("CPQHOST-MIB", "cpqHoSWRunningVersion"), ("CPQHOST-MIB", "cpqHoSWRunningStatus"), ("CPQHOST-MIB", "cpqHoSWRunningConfigStatus"), ("CPQHOST-MIB", "cpqHoSWRunningIdentifier"), ("CPQHOST-MIB", "cpqHoSWRunningRedundancyMode"),))
cpqHo2PowerThresholdTrap = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11018)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqPwrWarnType"), ("CPQHOST-MIB", "cpqPwrWarnThreshold"), ("CPQHOST-MIB", "cpqPwrWarnDuration"), ("CPQHOST-MIB", "cpqSerialNum"), ("CPQHOST-MIB", "cpqServerUUID"),))
cpqHoBootPagingFileOrFreeSpaceTooSmallTrap = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11019)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoCrashDumpState"), ("CPQHOST-MIB", "cpqHoBootPagingFileSize"), ("CPQHOST-MIB", "cpqHoBootPagingFileVolumeFreeSpace"), ("CPQHOST-MIB", "cpqHoBootPagingFileMinimumSize"),))
cpqHoMibHealthStatusArrayChangeTrap = NotificationType((1, 3, 6, 1, 4, 1, 232) + (0,11020)).setObjects(*(("CPQHOST-MIB", "sysName"), ("CPQHOST-MIB", "cpqHoTrapFlags"), ("CPQHOST-MIB", "cpqHoMibHealthStatusArray"),))
mibBuilder.exportSymbols("CPQHOST-MIB", cpqHoUtil=cpqHoUtil, cpqHoFileSysTable=cpqHoFileSysTable, cpqHoFileSysDesc=cpqHoFileSysDesc, cpqHoFileSys=cpqHoFileSys, cpqHoClientIndex=cpqHoClientIndex, cpqHoOsCommonModuleDate=cpqHoOsCommonModuleDate, cpqHoProcessCountWarning=cpqHoProcessCountWarning, cpqHoAppErrorTrap=cpqHoAppErrorTrap, cpqHoCodeServer=cpqHoCodeServer, cpqHoMibRevMinor=cpqHoMibRevMinor, cpqHoTelnet=cpqHoTelnet, cpqHo2NicStatusFailed=cpqHo2NicStatusFailed, cpqHoIfPhysMapPort=cpqHoIfPhysMapPort, cpqHoMibHealthStatusArrayChangeTrap=cpqHoMibHealthStatusArrayChangeTrap, cpqHoFwVerXmlString=cpqHoFwVerXmlString, cpqHoSwVer=cpqHoSwVer, cpqHoPhysicalMemoryFree=cpqHoPhysicalMemoryFree, cpqHoInfo=cpqHoInfo, cpqHoCrashDumpCondition=cpqHoCrashDumpCondition, cpqHoOsCommonModulePurpose=cpqHoOsCommonModulePurpose, cpqHoSwPerfAppErrorDesc=cpqHoSwPerfAppErrorDesc, cpqHoComponent=cpqHoComponent, cpqHoSWRunningTable=cpqHoSWRunningTable, cpqHoGeneric=cpqHoGeneric, cpqHoSWRunningEventTime=cpqHoSWRunningEventTime, cpqHoSWRunningCount=cpqHoSWRunningCount, cpqHoSWRunningRedundancyMode=cpqHoSWRunningRedundancyMode, cpqHoSwVerDate=cpqHoSwVerDate, cpqHoTrapFlags=cpqHoTrapFlags, cpqHosysDescr=cpqHosysDescr, cpqHoCrashDumpMonitoring=cpqHoCrashDumpMonitoring, cpqPwrThreshold=cpqPwrThreshold, cpqHoOsCommonModuleIndex=cpqHoOsCommonModuleIndex, cpqHoCpuUtilHwLocation=cpqHoCpuUtilHwLocation, cpqHoIfPhysMapMemBaseAddr=cpqHoIfPhysMapMemBaseAddr, cpqSerialNum=cpqSerialNum, cpqHoSWRunningStatus=cpqHoSWRunningStatus, cpqHoSwVerVersionBinary=cpqHoSwVerVersionBinary, cpqHoOsCommonModuleVersion=cpqHoOsCommonModuleVersion, cpqHoMemory=cpqHoMemory, cpqHoBootPagingFileOrFreeSpaceTooSmallTrap=cpqHoBootPagingFileOrFreeSpaceTooSmallTrap, cpqHoBootPagingFileVolumeFreeSpace=cpqHoBootPagingFileVolumeFreeSpace, cpqHo2PowerThresholdTrap=cpqHo2PowerThresholdTrap, cpqHoFileSysAllocUnitsUsed=cpqHoFileSysAllocUnitsUsed, cpqHoSWRunning=cpqHoSWRunning, cpqHoSWRunningName=cpqHoSWRunningName, cpqHoOsCommonModuleName=cpqHoOsCommonModuleName, cpqHoSWRunningIdentifier=cpqHoSWRunningIdentifier, cpqHoPhysicalMemorySize=cpqHoPhysicalMemorySize, cpqHoCpuUtilUnitIndex=cpqHoCpuUtilUnitIndex, cpqHoMibRev=cpqHoMibRev, cpqHoFileSysPercentSpaceUsed=cpqHoFileSysPercentSpaceUsed, cpqHoCrashDumpNotEnabledTrap=cpqHoCrashDumpNotEnabledTrap, cpqHoCpuUtilFiveMin=cpqHoCpuUtilFiveMin, cpqHoIfPhysMapTable=cpqHoIfPhysMapTable, cpqHoMibHealthStatusArray=cpqHoMibHealthStatusArray, cpqHoSwVerDescription=cpqHoSwVerDescription, cpqHoSystemRoleDetail=cpqHoSystemRoleDetail, cpqHoFileSysSpaceTotal=cpqHoFileSysSpaceTotal, cpqPwrWarnDuration=cpqPwrWarnDuration, cpqHoSwVerType=cpqHoSwVerType, cpqHoIfPhysMapDuplexState=cpqHoIfPhysMapDuplexState, cpqHoFwVerCategory=cpqHoFwVerCategory, cpqHoIfPhysMapDma=cpqHoIfPhysMapDma, cpqHoGenericTrap=cpqHoGenericTrap, cpqHoSWRunningEntry=cpqHoSWRunningEntry, cpqHoHWInfo=cpqHoHWInfo, cpqHoClientCommunity=cpqHoClientCommunity, cpqHoSystemStatus=cpqHoSystemStatus, cpqHoInterface=cpqHoInterface, cpqHo2NicStatusOk2=cpqHo2NicStatusOk2, cpqHoClientDelete=cpqHoClientDelete, cpqHoSWRunningStatusChangeTrap=cpqHoSWRunningStatusChangeTrap, cpqHoVersion=cpqHoVersion, cpqHoIfPhysMapCondition=cpqHoIfPhysMapCondition, cpqHoConfigChangedDate=cpqHoConfigChangedDate, cpqHo2NicSwitchoverOccurred=cpqHo2NicSwitchoverOccurred, cpqHoFwVerDeviceType=cpqHoFwVerDeviceType, cpqHoFwVerKeyString=cpqHoFwVerKeyString, cpqHoProcessCountNormal=cpqHoProcessCountNormal, cpqHoIfPhysMapOverallCondition=cpqHoIfPhysMapOverallCondition, cpqHoClientName=cpqHoClientName, cpqHoClientTable=cpqHoClientTable, cpqHoMaxLogicalCPUSupported=cpqHoMaxLogicalCPUSupported, cpqHoClientLastModified=cpqHoClientLastModified, cpqHoFwVerLocation=cpqHoFwVerLocation, cpqHoMibCondition=cpqHoMibCondition, cpqHoClientEntry=cpqHoClientEntry, cpqHo2GenericTrap=cpqHo2GenericTrap, cpqHoCpuUtilHour=cpqHoCpuUtilHour, cpqHostOs=cpqHostOs, cpqHoCriticalSoftwareUpdateData=cpqHoCriticalSoftwareUpdateData, cpqServerUUID=cpqServerUUID, cpqHoIfPhysMapIrq=cpqHoIfPhysMapIrq, cpqHoSystemName=cpqHoSystemName, cpqHoClientIpAddress=cpqHoClientIpAddress, cpqPwrWarnThreshold=cpqPwrWarnThreshold, cpqHoSystemRole=cpqHoSystemRole, cpqHoHWInfoPlatform=cpqHoHWInfoPlatform, cpqHo2NicStatusOk=cpqHo2NicStatusOk, cpqHoIfPhysMapSlot=cpqHoIfPhysMapSlot, cpqHoTrapInfo=cpqHoTrapInfo, cpqHoFileSysShortDesc=cpqHoFileSysShortDesc, cpqHoCpuUtilTable=cpqHoCpuUtilTable, cpqHoOsCommon=cpqHoOsCommon, cpqHoIfPhysMapIndex=cpqHoIfPhysMapIndex, cpqHoPagingMemorySize=cpqHoPagingMemorySize, cpqHoBootPagingFileSize=cpqHoBootPagingFileSize, cpqHoFileSysEntry=cpqHoFileSysEntry, cpqHoOsType=cpqHoOsType, cpqHoClientIpxAddress=cpqHoClientIpxAddress, cpqHoSwVerEntry=cpqHoSwVerEntry, cpqHoMibRevMajor=cpqHoMibRevMajor, cpqHoOsCommonModuleEntry=cpqHoOsCommonModuleEntry, cpqHoPagingMemoryFree=cpqHoPagingMemoryFree, cpqHoCpuUtilMin=cpqHoCpuUtilMin, cpqHoFwVerTable=cpqHoFwVerTable, cpqHoSWRunningIndex=cpqHoSWRunningIndex, cpqHoMibStatusArray=cpqHoMibStatusArray, cpqHoSwVerNextIndex=cpqHoSwVerNextIndex, cpqHo2AppErrorTrap=cpqHo2AppErrorTrap, cpqHoOsCommonModuleTable=cpqHoOsCommonModuleTable, cpqHoSWRunningState=cpqHoSWRunningState, cpqHoGUIDCanonical=cpqHoGUIDCanonical, cpqHoProcessEventTrap=cpqHoProcessEventTrap, cpqHoSwVerTable=cpqHoSwVerTable, cpqHoSWRunningDesc=cpqHoSWRunningDesc, cpqHoIfPhysMapIoBaseAddr=cpqHoIfPhysMapIoBaseAddr, cpqHoSwVerAgentsVer=cpqHoSwVerAgentsVer, cpqHoSWRunningCountMin=cpqHoSWRunningCountMin, cpqHoOsCommonPollFreq=cpqHoOsCommonPollFreq, cpqHoFileSysCondition=cpqHoFileSysCondition, cpqHoCpuUtilEntry=cpqHoCpuUtilEntry, cpqHoSWRunningMonitor=cpqHoSWRunningMonitor, cpqHoGenericData=cpqHoGenericData, cpqHoSWRunningVersion=cpqHoSWRunningVersion, cpqHoFwVerEntry=cpqHoFwVerEntry, cpqHoSwVerName=cpqHoSwVerName, cpqHoFwVerIndex=cpqHoFwVerIndex, cpqHoClientID=cpqHoClientID, cpqHoSwVerLocation=cpqHoSwVerLocation, cpqHoBootPagingFileMinimumSize=cpqHoBootPagingFileMinimumSize, cpqHoFwVerUpdateMethod=cpqHoFwVerUpdateMethod, cpqHoSWRunningCountMax=cpqHoSWRunningCountMax, cpqHoSwVerIndex=cpqHoSwVerIndex, cpqHoDesc=cpqHoDesc, cpqHoFileSysIndex=cpqHoFileSysIndex, cpqHoGUID=cpqHoGUID, cpqHo2NicSwitchoverOccurred2=cpqHo2NicSwitchoverOccurred2, cpqHoSwVerStatus=cpqHoSwVerStatus, cpqHoFileSysStatus=cpqHoFileSysStatus, cpqHoSwPerf=cpqHoSwPerf, cpqHoFwVerVersion=cpqHoFwVerVersion, cpqHoFwVer=cpqHoFwVer, cpqHoCrashDumpState=cpqHoCrashDumpState, cpqHoCriticalSoftwareUpdateTrap=cpqHoCriticalSoftwareUpdateTrap, cpqHoIfPhysMapEntry=cpqHoIfPhysMapEntry, cpqHo2NicStatusFailed2=cpqHo2NicStatusFailed2, cpqHoCpuUtilThirtyMin=cpqHoCpuUtilThirtyMin, cpqHoFileSysSpaceUsed=cpqHoFileSysSpaceUsed, compaq=compaq, cpqHoWebMgmtPort=cpqHoWebMgmtPort, cpqHoSWRunningConfigStatus=cpqHoSWRunningConfigStatus, cpqHoSwVerVersion=cpqHoSwVerVersion, cpqHoName=cpqHoName, cpqHoFwVerDisplayName=cpqHoFwVerDisplayName, cpqHoSWRunningDate=cpqHoSWRunningDate, cpqPwrWarnType=cpqPwrWarnType, cpqHoIfPhysMap=cpqHoIfPhysMap, cpqHoBootPagingFileTooSmallTrap=cpqHoBootPagingFileTooSmallTrap, cpqHoClients=cpqHoClients, cpqHoFileSysAllocUnitsTotal=cpqHoFileSysAllocUnitsTotal, cpqHoSwRunningTrapDesc=cpqHoSwRunningTrapDesc)



# Copyright 2017 Hewlett Packard Enterprise Development LP
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

"""
There is no explicit collection for Drives. That said, a URI link as
"/redfish/v1/Systems/1/Storage/1/Drives" will be an invalid URI.
"""

from sushy.resources import base

from proliantutils.redfish.resources.system.storage import mappings


class Drive(base.ResourceBase):
    """This class represents the Drive resource"""

    capacity_bytes = base.Field('CapacityBytes', adapter=int)
    """The size in bytes of this Drive"""

    media_type = base.MappedField('MediaType', mappings.MEDIA_TYPE_MAP)
    """The type of media contained in this drive"""

    protocol = base.MappedField('Protocol', mappings.DEVICE_PROTOCOLS_MAP)
    """The protocol this drive is using to communicate to the storage
    controller."""

    rotation_speed_rpm = base.Field('RotationSpeedRPM', adapter=int)
    """The rotation speed of this Drive in Revolutions per Minute (RPM)."""



# Copyright 2017 Hewlett Packard Enterprise Development LP
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

__author__ = 'HPE'

import json
from unittest import mock

from sushy import exceptions
from sushy.resources.manager import virtual_media as sushy_virt_media
import testtools

from proliantutils import exception
from proliantutils.redfish.resources.manager import constants
from proliantutils.redfish.resources.manager import virtual_media


class VirtualMediaCollectionTestCase(testtools.TestCase):

    def setUp(self):
        super(VirtualMediaCollectionTestCase, self).setUp()
        self.conn = mock.MagicMock()
        with open('proliantutils/tests/redfish/'
                  'json_samples/vmedia_collection.json') as f:
            self.conn.get.return_value.json.return_value = (
                json.loads(f.read()))

        self.vmedia_coll_inst = virtual_media.VirtualMediaCollection(
            self.conn, '/redfish/v1/Managers/1/VirtualMedia',
            redfish_version='1.0.2')

    def test_get_member_device(self):
        with open('proliantutils/tests/redfish/'
                  'json_samples/vmedia.json', 'r') as f:
            self.conn.get.return_value.json.return_value = (
                json.loads(f.read())['default'])

        obj = self.vmedia_coll_inst.get_member_device(
            constants.VIRTUAL_MEDIA_CD)

        self.assertIsInstance(obj, virtual_media.VirtualMedia)


class VirtualMediaTestCase(testtools.TestCase):

    def setUp(self):
        super(VirtualMediaTestCase, self).setUp()
        self.conn = mock.MagicMock()
        with open('proliantutils/tests/redfish/'
                  'json_samples/vmedia.json') as f:
            self.json_doc = json.load(f)

        self.conn.get.return_value.json.return_value = self.json_doc[
            'default']

        self.vmedia_inst = virtual_media.VirtualMedia(
            self.conn, '/redfish/v1/Managers/1/VirtualMedia/2',
            redfish_version='1.0.2')

    def test__parse_attributes(self):
        self.vmedia_inst._parse_attributes(self.json_doc['default'])
        self.assertEqual(['cd', 'dvd'], self.vmedia_inst.media_types)
        self.assertEqual(False, self.vmedia_inst.inserted)

    def test__parse_attributes_missing_actions(self):
        self.vmedia_inst.json.pop('Oem')
        self.assertRaisesRegex(
            exceptions.MissingAttributeError, 'attribute Oem/Hpe/Actions',
            self.vmedia_inst._parse_attributes, self.json_doc)

    def test__get_action_element_insert(self):
        value = self.vmedia_inst._get_action_element('insert')
        self.assertEqual("/redfish/v1/Managers/1/VirtualMedia/2/Actions/Oem/"
                         "Hpe/HpeiLOVirtualMedia.InsertVirtualMedia/",
                         value.target_uri)

    def test__get_action_element_missing_insert_action(self):
        self.vmedia_inst._hpe_actions.insert_vmedia = None
        self.assertRaisesRegex(
            exception.MissingAttributeError,
            'attribute #HpeiLOVirtualMedia.InsertVirtualMedia',
            self.vmedia_inst._get_action_element, 'insert')

    def test__get_action_element_eject(self):
        value = self.vmedia_inst._get_action_element('eject')
        self.assertEqual("/redfish/v1/Managers/1/VirtualMedia/2/Actions/Oem/"
                         "Hpe/HpeiLOVirtualMedia.EjectVirtualMedia/",
                         value.target_uri)

    def test__get__action_element_missing_eject_action(self):
        self.vmedia_inst._hpe_actions.eject_vmedia = None
        self.assertRaisesRegex(
            exception.MissingAttributeError,
            'attribute #HpeiLOVirtualMedia.EjectVirtualMedia',
            self.vmedia_inst._get_action_element, 'eject')

    @mock.patch.object(sushy_virt_media.VirtualMedia, 'insert_media')
    def test_insert_media_sushy(self, insert_mock):
        insert_mock.return_value = None
        url = "http://1.2.3.4:5678/xyz.iso"
        self.vmedia_inst.insert_media(url)
        insert_mock.assert_called_once_with(url, write_protected=True)

    @mock.patch.object(sushy_virt_media.VirtualMedia, 'insert_media')
    def test_insert_media(self, insert_mock):
        url = "http://1.2.3.4:5678/xyz.iso"
        insert_mock.side_effect = exceptions.SushyError
        self.vmedia_inst.insert_media(url)
        self.vmedia_inst._conn.post.assert_called_once_with(
            "/redfish/v1/Managers/1/VirtualMedia/2/Actions/Oem/Hpe/"
            "HpeiLOVirtualMedia.InsertVirtualMedia/",
            data={'Image': url})

    @mock.patch.object(virtual_media.VirtualMedia, 'eject_media')
    def test_eject_media_sushy(self, eject_mock):
        eject_mock.return_value = None
        self.vmedia_inst.eject_media()
        self.vmedia_inst.eject_media.assert_called_once()

    @mock.patch.object(sushy_virt_media.VirtualMedia, 'eject_media')
    def test_eject_media(self, eject_mock):
        eject_mock.side_effect = exceptions.SushyError
        self.vmedia_inst.eject_media()
        self.vmedia_inst._conn.post.assert_called_once_with(
            "/redfish/v1/Managers/1/VirtualMedia/2/Actions/Oem/Hpe/"
            "HpeiLOVirtualMedia.EjectVirtualMedia/",
            data={})

    def test_set_vm_status(self):
        value = {'Oem': {'Hpe': {'BootOnNextServerReset': True}}}
        self.vmedia_inst.set_vm_status(True)
        self.vmedia_inst._conn.patch.assert_called_once_with(
            "/redfish/v1/Managers/1/VirtualMedia/2",
            data=value)



# Copyright 2017 Hewlett Packard Enterprise Development LP
#
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import sushy
from sushy.resources import base
from sushy.resources.system import ethernet_interface
from sushy import utils as sushy_utils


class EthernetInterface(ethernet_interface.EthernetInterface):

    uefi_device_path = base.Field('UefiDevicePath')


class EthernetInterfaceCollection(base.ResourceCollectionBase):

    @property
    def _resource_type(self):
        return EthernetInterface

    @property
    @sushy_utils.cache_it
    def summary(self):
        """property to return the summary MAC addresses and state

        This filters the MACs whose health is OK,
        and in 'Enabled' State would be returned.
        The returned format will be {<port_id>: <mac_address>}.
        This is because RIBCL returns the data in format
        {'Port 1': 'aa:bb:cc:dd:ee:ff'} and ironic ilo drivers inspection
        consumes the data in this format.
        Note: 'Id' is referred to as "Port number".
        """
        mac_dict = {}
        for eth in self.get_members():
            if eth.mac_address is not None:
                if (eth.status is not None
                        and eth.status.health == sushy.HEALTH_OK
                        and eth.status.state == sushy.STATE_ENABLED):
                    mac_dict.update(
                        {'Port ' + eth.identity: eth.mac_address})
        return mac_dict

    def get_uefi_device_path_by_mac(self, mac):
        """Return uefi device path of mac"""
        for nic in self.get_members():
            if nic.mac_address.lower() == mac.lower():
                return nic.uefi_device_path

    def get_all_macs(self):
        """Return list of macs available on system"""
        macs = [mac.mac_address.lower() for mac in self.get_members()]
        return macs



# Copyright 2021 Hewlett Packard Enterprise Development LP
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import json
from unittest import mock

import testtools

from proliantutils.redfish.resources.chassis import devices


class DevicesTestCase(testtools.TestCase):

    def setUp(self):
        super(DevicesTestCase, self).setUp()
        self.conn = mock.Mock()
        dev_file = 'proliantutils/tests/redfish/json_samples/devices.json'
        with open(dev_file, 'r') as f:
            self.json_doc = json.load(f)
        self.conn.get.return_value.json.return_value = self.json_doc

        dev_path = "/redfish/v1/Chassis/1/Devices/9"
        self.dev = devices.Devices(
            self.conn, dev_path, '1.0.2', None)

    def test__parse_attributes(self):
        self.dev._parse_attributes(self.json_doc)
        self.assertEqual('1.0.2', self.dev.redfish_version)
        self.assertEqual('1', self.dev.identity)
        self.assertEqual('Embedded Video Controller', self.dev.name)
        self.assertEqual('', self.dev.manufacturer)


class DevicesCollectionTestCase(testtools.TestCase):

    def setUp(self):
        super(DevicesCollectionTestCase, self).setUp()
        self.conn = mock.Mock()
        with open('proliantutils/tests/redfish/json_samples/'
                  'devices_collection.json') as f:
            self.json_doc = json.load(f)
        self.conn.get.return_value.json.return_value = self.json_doc
        self.dev_col = devices.DevicesCollection(
            self.conn, '/redfish/v1/Chassis/1/Devices',
            redfish_version='1.0.2')

    def test__parse_attributes(self):
        self.dev_col._parse_attributes(self.json_doc)
        self.assertEqual('1.0.2', self.dev_col.redfish_version)
        self.assertEqual('Devices', self.dev_col.name)
        path = ('/redfish/v1/Chassis/1/Devices/9')
        self.assertEqual(path, self.dev_col.members_identities)

    @mock.patch.object(devices, 'Devices', autospec=True)
    def test_get_member(self, mock_dev):
        self.dev_col.get_member(
            '/redfish/v1/Chassis/1/Devices/9')
        mock_dev.assert_called_once_with(
            self.dev_col._conn,
            ('/redfish/v1/Chassis/1/Devices/9'),
            self.dev_col.redfish_version, None)

    @mock.patch.object(devices, 'Devices', autospec=True)
    def test_get_members(self, mock_dev):
        members = self.dev_col.get_members()
        path_list = ["/redfish/v1/Chassis/1/Devices/9"]
        calls = [
            mock.call(self.dev_col._conn, path_list[0],
                      self.dev_col.redfish_version, None)
        ]
        mock_dev.assert_has_calls(calls)
        self.assertIsInstance(members, list)
        self.assertEqual(1, len(members))

    def test_vendor_dict(self):
        self.conn.get.return_value.json.reset_mock()
        val = []
        path = ('proliantutils/tests/redfish/json_samples/'
                'devices.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        self.conn.get.return_value.json.side_effect = val
        expected = {'9': 'NULL'}
        actual = self.dev_col.vendor_dict
        self.assertEqual(expected, actual)

    def test_pci_devices_uris(self):
        self.conn.get.return_value.json.reset_mock()
        val = []
        path = ('proliantutils/tests/redfish/json_samples/'
                'devices.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        self.conn.get.return_value.json.side_effect = val
        expected = {'9': ["/redfish/v1/Systems/1/PCIDevices/6"]}
        actual = self.dev_col.pci_devices_uris
        self.assertEqual(expected, actual)

    def test_vendor_devices_dict(self):
        self.conn.get.return_value.json.reset_mock()
        val = []
        path = ('proliantutils/tests/redfish/json_samples/'
                'devices.json')
        with open(path, 'r') as f:
            val.append(json.loads(f.read()))
        self.conn.get.return_value.json.side_effect = val
        expected = {'9': 'Embedded Video Controller'}
        actual = self.dev_col.vendor_devices_dict
        self.assertEqual(expected, actual)



# Copyright 2015 Hewlett-Packard Development Company, L.P.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

"""Logger utility for proliantutils"""

import logging


base_logger = logging.getLogger('proliantutils')
base_logger.addHandler(logging.NullHandler())


def get_logger(name):
    """Return a logger with the specified name

    If no name is specified then it returns the base logger
    with the name, 'proliantutils'.

    :param name: logger name
    """
    if not name:
        return base_logger

    logger = logging.getLogger(name)
    return logger



# Copyright 2018-2022 Hewlett Packard Enterprise Development LP
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import json
from unittest import mock

import sushy
from sushy.resources.system import system as sushy_system
import testtools

from proliantutils import exception
from proliantutils.redfish.resources.system import bios
from proliantutils.redfish.resources.system import constants as sys_cons
from proliantutils.redfish.resources.system import ethernet_interface
from proliantutils.redfish.resources.system import memory
from proliantutils.redfish.resources.system import secure_boot
from proliantutils.redfish.resources.system import smart_storage_config
from proliantutils.redfish.resources.system.storage import array_controller
from proliantutils.redfish.resources.system.storage import simple_storage
from proliantutils.redfish.resources.system.storage import smart_storage
from proliantutils.redfish.resources.system.storage import storage
from proliantutils.redfish.resources.system import system
from proliantutils.redfish import utils


class HPESystemTestCase(testtools.TestCase):

    def setUp(self):
        super(HPESystemTestCase, self).setUp()
        self.conn = mock.MagicMock()
        self.conn.get.return_value.headers = {'Allow': 'GET,HEAD'}
        with open('proliantutils/tests/redfish/'
                  'json_samples/system.json', 'r') as f:
            system_json = json.loads(f.read())
        self.conn.get.return_value.json.return_value = system_json['default']

        self.sys_inst = system.HPESystem(
            self.conn, '/redfish/v1/Systems/1',
            redfish_version='1.0.2')

    def test_attributes(self):
        self.assertEqual(sys_cons.SUPPORTED_LEGACY_BIOS_AND_UEFI,
                         self.sys_inst.supported_boot_mode)

    def test__get_hpe_one_button_secure_erase_action_element(self):
        value = self.sys_inst._get_hpe_one_button_secure_erase_action_element()
        self.assertEqual("/redfish/v1/Systems/1/Actions/Oem/Hpe/"
                         "HpeComputerSystemExt.SecureSystemErase",
                         value.target_uri)

    def test__get_hpe_one_button_secure_erase_action_element_missing_action(
            self):
        (self.sys_inst._hpe_actions.
         computer_system_ext_one_button_secure_erase) = None
        self.assertRaisesRegex(
            exception.MissingAttributeError,
            'Oem/Hpe/Actions/#HpeComputerSystemExt.SecureSystemErase is '
            'missing',
            self.sys_inst._get_hpe_one_button_secure_erase_action_element)

    def test__get_hpe_push_power_button_action_element(self):
        value = self.sys_inst._get_hpe_push_power_button_action_element()
        self.assertEqual("/redfish/v1/Systems/1/Actions/Oem/Hpe/"
                         "HpeComputerSystemExt.PowerButton/",
                         value.target_uri)
        self.assertEqual(["Press", "PressAndHold"], value.allowed_values)

    def test__get_hpe_push_power_button_action_element_missing_action(self):
        self.sys_inst._hpe_actions.computer_system_ext_powerbutton = None
        self.assertRaisesRegex(
            exception.MissingAttributeError,
            'Oem/Hpe/Actions/#HpeComputerSystemExt.PowerButton is missing',
            self.sys_inst._get_hpe_push_power_button_action_element)

    def test_push_power_button(self):
        self.sys_inst.push_power_button(
            sys_cons.PUSH_POWER_BUTTON_PRESS)
        self.sys_inst._conn.post.assert_called_once_with(
            '/redfish/v1/Systems/1/Actions/Oem/Hpe/'
            'HpeComputerSystemExt.PowerButton/',
            data={'PushType': 'Press'})

    def test_push_power_button_invalid_value(self):
        self.assertRaises(exception.InvalidInputError,
                          self.sys_inst.push_power_button, 'invalid-value')

    def test_bios_settings(self):
        self.conn.get.return_value.json.reset_mock()
        with open('proliantutils/tests/redfish/'
                  'json_samples/bios.json', 'r') as f:
            self.conn.get.return_value.json.return_value = json.loads(f.read())
        actual_bios = self.sys_inst.bios_settings
        self.assertIsInstance(actual_bios,
                              bios.BIOSSettings)
        self.conn.get.return_value.json.assert_called_once_with()
        # reset mock
        self.conn.get.return_value.json.reset_mock()
        self.assertIs(actual_bios,
                      self.sys_inst.bios_settings)
        self.conn.get.return_value.json.assert_not_called()

    @mock.patch.object(sushy_system.System, 'set_system_boot_source')
    def test_update_persistent_boot_persistent(self,
                                               set_system_boot_source_mock):
        self.sys_inst.update_persistent_boot(['CDROM'], persistent=True)
        set_system_boot_source_mock.assert_called_once_with(
            sushy.BOOT_SOURCE_TARGET_CD,
            enabled=sushy.BOOT_SOURCE_ENABLED_CONTINUOUS)

    @mock.patch.object(sushy_system.System, 'set_system_boot_source')
    def test_update_persistent_boot_device_unknown_persistent(
            self, set_system_boot_source_mock):
        self.sys_inst.update_persistent_boot(['unknown'], persistent=True)
        set_system_boot_source_mock.assert_called_once_with(
            sushy.BOOT_SOURCE_TARGET_NONE,
            enabled=sushy.BOOT_SOURCE_ENABLED_CONTINUOUS)

    @mock.patch.object(sushy_system.System, 'set_system_boot_source')
    def test_update_persistent_boot_not_persistent(
            self, set_system_boot_source_mock):
        self.sys_inst.update_persistent_boot(['CDROM'], persistent=False)
        set_system_boot_source_mock.assert_called_once_with(
            sushy.BOOT_SOURCE_TARGET_CD,
            enabled=sushy.BOOT_SOURCE_ENABLED_ONCE)

    def test_bios_settings_on_refresh(self):
        # | GIVEN |
        with open('proliantutils/tests/redfish/json_samples/bios.json',
                  'r') as f:
            self.conn.get.return_value.json.return_value = json.loads(f.read())
        # | WHEN & THEN |
        actual_bios_settings = self.sys_inst.bios_settings
        self.assertIsInstance(actual_bios_settings,
                              bios.BIOSSettings)

        # On refreshing the system instance...
        with open('proliantutils/tests/redfish/'
                  'json_samples/system.json', 'r') as f:
            self.conn.get.return_value.json.return_value = (
                json.loads(f.read())['default'])

        self.sys_inst.invalidate()
        self.sys_inst.refresh(force=False)

        # | WHEN & THEN |
        self.assertTrue(actual_bios_settings._is_stale)

        # | GIVEN |
        with open('proliantutils/tests/redfish/json_samples/bios.json',
                  'r') as f:
            self.conn.get.return_value.json.return_value = json.loads(f.read())
        # | WHEN & THEN |
        self.assertIsInstance(self.sys_inst.bios_settings,
                              bios.BIOSSettings)
        self.assertFalse(actual_bios_settings._is_stale)

    def test_update_persistent_boot_uefi_target(self):
        with open('proliantutils/tests/redfish/'
                  'json_samples/system.json', 'r') as f:
            system_json = (json.loads(f.read())[
                'System_op_for_update_persistent_boot_uefi_target'])
        self.sys_inst.uefi_target_override_devices = (system_json[
            'Boot']['UefiTargetBootSourceOverride@Redfish.AllowableValues'])
        self.sys_inst.update_persistent_boot(['ISCSI'], persistent=True)
        uefi_boot_settings = {
            'Boot': {'UefiTargetBootSourceOverride': 'PciRoot(0x0)/Pci(0x1C,0x0)/Pci(0x0,0x0)/MAC(98F2B3EEF886,0x0)/IPv4(172.17.1.32)/iSCSI(iqn.2001-04.com.paresh.boot:volume.bin,0x1,0x0,None,None,None,TCP)'}  # noqa
        }

        calls = [mock.call('/redfish/v1/Systems/1', data=uefi_boot_settings),
                 mock.call('/redfish/v1/Systems/1',
                           data={'Boot':
                                 {'BootSourceOverrideTarget': 'UefiTarget',
                                  'BootSourceOverrideEnabled': 'Continuous'}},
                           etag=None)]
        self.sys_inst._conn.patch.assert_has_calls(calls)

    def test_update_persistent_boot_uefi_no_iscsi_device(self):
        self.assertRaisesRegex(
            exception.IloError,
            'No UEFI iSCSI bootable device found on system.',
            self.sys_inst.update_persistent_boot, ['ISCSI'], True)

    def test_update_persistent_boot_uefi_target_fail(self):
        update_mock = mock.PropertyMock(
            side_effect=sushy.exceptions.SushyError)
        type(self.sys_inst).uefi_target_override_devices = update_mock
        self.assertRaisesRegex(
            exception.IloError,
            'Unable to get uefi target override devices.',
            self.sys_inst.update_persistent_boot, ['ISCSI'], True)
        del type(self.sys_inst).uefi_target_override_devices

    def test_pci_devices(self):
        pci_dev_return_value = None
        pci_dev1_return_value = None
        pci_coll_return_value = None
        self.conn.get.return_value.json.reset_mock()
        with open('proliantutils/tests/redfish/'
                  'json_samples/pci_device_collection.json') as f:
            pci_coll_return_value = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/pci_device.json') as f:
            pci_dev_return_value = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/pci_device1.json') as f:
            pci_dev1_return_value = json.loads(f.read())
            self.conn.get.return_value.json.side_effect = (
                [pci_coll_return_value, pci_dev_return_value,
                 pci_dev1_return_value])
        actual_pci = self.sys_inst.pci_devices
        self.conn.get.return_value.json.reset_mock()
        self.assertIs(actual_pci,
                      self.sys_inst.pci_devices)
        self.conn.get.return_value.json.assert_not_called()

    def test_secure_boot_with_missing_path_attr(self):
        def _get_secure_boot():
            return self.sys_inst.secure_boot

        self.sys_inst._json.pop('SecureBoot')
        self.assertRaisesRegex(
            exception.MissingAttributeError,
            'attribute SecureBoot is missing',
            _get_secure_boot)

    def test_secure_boot(self):
        # | GIVEN |
        self.conn.get.return_value.json.reset_mock()
        with open('proliantutils/tests/redfish/json_samples/secure_boot.json',
                  'r') as f:
            self.conn.get.return_value.json.return_value = (
                json.loads(f.read())['default'])
        # | WHEN |
        actual_secure_boot = self.sys_inst.secure_boot
        # | THEN |
        self.assertIsInstance(actual_secure_boot,
                              secure_boot.SecureBoot)
        self.conn.get.return_value.json.assert_called_once_with()

        # reset mock
        self.conn.get.return_value.json.reset_mock()
        # | WHEN & THEN |
        # tests for same object on invoking subsequently
        self.assertIs(actual_secure_boot,
                      self.sys_inst.secure_boot)
        self.conn.get.return_value.json.assert_not_called()

    def test_secure_boot_on_refresh(self):
        # | GIVEN |
        with open('proliantutils/tests/redfish/json_samples/secure_boot.json',
                  'r') as f:
            self.conn.get.return_value.json.return_value = (
                json.loads(f.read())['default'])
        # | WHEN & THEN |
        actual_secure_boot = self.sys_inst.secure_boot
        self.assertIsInstance(actual_secure_boot, secure_boot.SecureBoot)

        # On refreshing the system instance...
        with open('proliantutils/tests/redfish/'
                  'json_samples/system.json', 'r') as f:
            self.conn.get.return_value.json.return_value = (
                json.loads(f.read())['default'])

        self.sys_inst.invalidate()
        self.sys_inst.refresh(force=False)

        # | WHEN & THEN |
        self.assertTrue(actual_secure_boot._is_stale)

        # | GIVEN |
        with open('proliantutils/tests/redfish/json_samples/secure_boot.json',
                  'r') as f:
            self.conn.get.return_value.json.return_value = (
                json.loads(f.read())['default'])
        # | WHEN & THEN |
        self.assertIsInstance(self.sys_inst.secure_boot,
                              secure_boot.SecureBoot)
        self.assertFalse(actual_secure_boot._is_stale)

    @mock.patch.object(utils, 'get_subresource_path_by')
    def test_get_hpe_sub_resource_collection_path(self, res_mock):
        res = 'EthernetInterfaces'
        res_mock.return_value = '/redfish/v1/Systems/1/EthernetInterfaces'
        path = self.sys_inst._get_hpe_sub_resource_collection_path(res)
        self.assertTrue(res_mock.called)
        self.assertEqual(path, res_mock.return_value)

    @mock.patch.object(utils, 'get_subresource_path_by')
    def test_get_hpe_sub_resource_collection_path_oem_path(self, res_mock):
        res = 'EthernetInterfaces'
        error_val = exception.MissingAttributeError
        oem_path = '/redfish/v1/Systems/1/EthernetInterfaces'
        res_mock.side_effect = [error_val, oem_path]
        path = self.sys_inst._get_hpe_sub_resource_collection_path(res)
        self.assertTrue(res_mock.called)
        self.assertEqual(path, oem_path)

    @mock.patch.object(utils, 'get_subresource_path_by')
    def test_get_hpe_sub_resource_collection_path_fail(self, res_mock):
        error_val = exception.MissingAttributeError
        res_mock.side_effect = [error_val, error_val]
        self.assertRaises(
            exception.MissingAttributeError,
            self.sys_inst._get_hpe_sub_resource_collection_path,
            'EthernetInterfaces')
        self.assertTrue(res_mock.called)

    def test_ethernet_interfaces(self):
        self.conn.get.return_value.json.reset_mock()
        eth_coll = None
        eth_value = None
        path = ('proliantutils/tests/redfish/json_samples/'
                'ethernet_interface_collection.json')
        with open(path, 'r') as f:
            eth_coll = json.loads(f.read())
        with open('proliantutils/tests/redfish/json_samples/'
                  'ethernet_interface.json', 'r') as f:
            eth_value = (json.loads(f.read())['default'])
        self.conn.get.return_value.json.side_effect = [eth_coll,
                                                       eth_value]
        actual_macs = self.sys_inst.ethernet_interfaces.summary
        self.assertEqual({'Port 1': '12:44:6A:3B:04:11'},
                         actual_macs)
        self.assertIsInstance(self.sys_inst.ethernet_interfaces,
                              ethernet_interface.EthernetInterfaceCollection)

    def test_ethernet_interfaces_oem(self):
        self.conn = mock.MagicMock()
        with open('proliantutils/tests/redfish/'
                  'json_samples/system.json', 'r') as f:
            system_json = json.loads(f.read())
        self.conn.get.return_value.json.return_value = (
            system_json['System_for_oem_ethernet_interfaces'])

        self.sys_inst = system.HPESystem(
            self.conn, '/redfish/v1/Systems/1',
            redfish_version='1.0.2')

        self.conn.get.return_value.json.reset_mock()
        eth_coll = None
        eth_value = None
        path = ('proliantutils/tests/redfish/json_samples/'
                'ethernet_interface_collection.json')
        with open(path, 'r') as f:
            eth_coll = json.loads(f.read())
        with open('proliantutils/tests/redfish/json_samples/'
                  'ethernet_interface.json', 'r') as f:
            eth_value = (json.loads(f.read())['default'])
        self.conn.get.return_value.json.side_effect = [eth_coll,
                                                       eth_value]
        actual_macs = self.sys_inst.ethernet_interfaces.summary
        self.assertEqual({'Port 1': '12:44:6A:3B:04:11'},
                         actual_macs)
        self.assertIsInstance(self.sys_inst.ethernet_interfaces,
                              ethernet_interface.EthernetInterfaceCollection)

    def test_smart_storage(self):
        self.conn.get.return_value.json.reset_mock()
        value = None
        with open('proliantutils/tests/redfish/json_samples/'
                  'smart_storage.json', 'r') as f:
            value = (json.loads(f.read()))
        self.conn.get.return_value.json.return_value = value
        value = self.sys_inst.smart_storage
        self.assertIsInstance(value, smart_storage.HPESmartStorage)

    def test_storages(self):
        self.conn.get.return_value.json.reset_mock()
        coll = None
        value = None
        path = ('proliantutils/tests/redfish/json_samples/'
                'storage_collection.json')
        with open(path, 'r') as f:
            coll = json.loads(f.read())
        with open('proliantutils/tests/redfish/json_samples/'
                  'storage.json', 'r') as f:
            value = (json.loads(f.read()))
        self.conn.get.return_value.json.side_effect = [coll, value]
        self.assertIsInstance(self.sys_inst.storages,
                              storage.StorageCollection)

    def test_simple_storages(self):
        self.conn.get.return_value.json.reset_mock()
        coll = None
        value = None
        path = ('proliantutils/tests/redfish/json_samples/'
                'simple_storage_collection.json')
        with open(path, 'r') as f:
            coll = json.loads(f.read())
        with open('proliantutils/tests/redfish/json_samples/'
                  'simple_storage.json', 'r') as f:
            value = (json.loads(f.read()))
        self.conn.get.return_value.json.side_effect = [coll, value]
        self.assertIsInstance(self.sys_inst.simple_storages,
                              simple_storage.SimpleStorageCollection)

    def test_simple_storage_on_refresh(self):
        with open('proliantutils/tests/redfish/json_samples/'
                  'simple_storage_collection.json',
                  'r') as f:
            self.conn.get.return_value.json.return_value = json.loads(f.read())
        actual_simple_storages = self.sys_inst.simple_storages
        self.assertIsInstance(actual_simple_storages,
                              simple_storage.SimpleStorageCollection)
        with open('proliantutils/tests/redfish/'
                  'json_samples/system.json', 'r') as f:
            self.conn.get.return_value.json.return_value = (
                json.loads(f.read())['default'])

        self.sys_inst.invalidate()
        self.sys_inst.refresh(force=False)

        self.assertTrue(actual_simple_storages._is_stale)

        with open('proliantutils/tests/redfish/json_samples/'
                  'simple_storage_collection.json', 'r') as f:
            self.conn.get.return_value.json.return_value = json.loads(f.read())
        self.assertIsInstance(self.sys_inst.simple_storages,
                              simple_storage.SimpleStorageCollection)
        self.assertFalse(actual_simple_storages._is_stale)

    def test_memory(self):
        self.conn.get.return_value.json.reset_mock()
        with open('proliantutils/tests/redfish/'
                  'json_samples/memory_collection.json', 'r') as f:
            self.conn.get.return_value.json.return_value = json.loads(f.read())
        actual_memory = self.sys_inst.memory
        self.assertIsInstance(actual_memory,
                              memory.MemoryCollection)
        self.conn.get.return_value.json.assert_called_once_with()
        # reset mock
        self.conn.get.return_value.json.reset_mock()
        self.assertIs(actual_memory,
                      self.sys_inst.memory)
        self.conn.get.return_value.json.assert_not_called()

    def test_memory_collection_on_refresh(self):
        # | GIVEN |
        with open('proliantutils/tests/redfish/json_samples/'
                  'memory_collection.json', 'r') as f:
            self.conn.get.return_value.json.return_value = json.loads(f.read())
        # | WHEN & THEN |
        actual_memory = self.sys_inst.memory
        self.assertIsInstance(actual_memory, memory.MemoryCollection)

        # On refreshing the system instance...
        with open('proliantutils/tests/redfish/'
                  'json_samples/system.json', 'r') as f:
            self.conn.get.return_value.json.return_value = (
                json.loads(f.read())['default'])

        self.sys_inst.invalidate()
        self.sys_inst.refresh(force=False)

        # | WHEN & THEN |
        self.assertTrue(actual_memory._is_stale)

        # | GIVEN |
        with open('proliantutils/tests/redfish/json_samples/'
                  'memory_collection.json', 'r') as f:
            self.conn.get.return_value.json.return_value = json.loads(f.read())
        # | WHEN & THEN |
        self.assertIsInstance(self.sys_inst.memory,
                              memory.MemoryCollection)
        self.assertFalse(actual_memory._is_stale)

    def test_storage_on_refresh(self):
        with open('proliantutils/tests/redfish/json_samples/'
                  'storage_collection.json',
                  'r') as f:
            self.conn.get.return_value.json.return_value = json.loads(f.read())
        actual_storages = self.sys_inst.storages
        self.assertIsInstance(actual_storages, storage.StorageCollection)
        # On refreshing the system instance...
        with open('proliantutils/tests/redfish/'
                  'json_samples/system.json', 'r') as f:
            self.conn.get.return_value.json.return_value = (
                json.loads(f.read())['default'])

        self.sys_inst.invalidate()
        self.sys_inst.refresh(force=False)

        self.assertTrue(actual_storages._is_stale)

        with open('proliantutils/tests/redfish/json_samples/'
                  'simple_storage_collection.json', 'r') as f:
            self.conn.get.return_value.json.return_value = json.loads(f.read())
        self.assertIsInstance(self.sys_inst.storages,
                              storage.StorageCollection)
        self.assertFalse(actual_storages._is_stale)

    def test_get_host_post_state(self):
        expected = sys_cons.POST_STATE_FINISHEDPOST
        self.assertEqual(expected, self.sys_inst.post_state)

    @mock.patch.object(smart_storage_config, 'HPESmartStorageConfig',
                       autospec=True)
    def test_get_smart_storage_config(self, mock_ssc):
        ssc_element = '/redfish/v1/systems/1/smartstorageconfig/'
        ssc_inst = self.sys_inst.get_smart_storage_config(ssc_element)
        self.assertIsInstance(ssc_inst,
                              smart_storage_config.HPESmartStorageConfig.
                              __class__)
        mock_ssc.assert_called_once_with(
            self.conn, "/redfish/v1/systems/1/smartstorageconfig/",
            redfish_version='1.0.2')

    @mock.patch.object(system.HPESystem, 'get_smart_storage_config')
    def test_delete_raid(self, get_smart_storage_config_mock):
        config_id = ['/redfish/v1/systems/1/smartstorageconfig/']
        type(self.sys_inst).smart_storage_config_identities = (
            mock.PropertyMock(return_value=config_id))
        self.sys_inst.delete_raid()
        get_smart_storage_config_mock.assert_called_once_with(config_id[0])
        (get_smart_storage_config_mock.return_value.
         delete_raid.assert_called_once_with())

    @mock.patch.object(system.HPESystem, 'get_smart_storage_config')
    def test_delete_raid_controller_failed(self,
                                           get_smart_storage_config_mock):
        config_id = ['/redfish/v1/systems/1/smartstorageconfig/',
                     '/redfish/v1/systems/1/smartstorageconfig1/',
                     '/redfish/v1/systems/1/smartstorageconfig2/']
        type(self.sys_inst).smart_storage_config_identities = (
            mock.PropertyMock(return_value=config_id))
        get_smart_storage_config_mock.return_value.delete_raid.side_effect = (
            [None, sushy.exceptions.SushyError, None])
        self.assertRaisesRegex(
            exception.IloError,
            "The Redfish controller failed to delete the "
            "raid configuration in one or more controllers with",
            self.sys_inst.delete_raid)

    @mock.patch.object(system.HPESystem, 'get_smart_storage_config')
    def test_delete_raid_logical_drive_not_found(
            self, get_smart_storage_config_mock):
        config_id = ['/redfish/v1/systems/1/smartstorageconfig/',
                     '/redfish/v1/systems/1/smartstorageconfig1/']
        type(self.sys_inst).smart_storage_config_identities = (
            mock.PropertyMock(return_value=config_id))
        get_smart_storage_config_mock.return_value.delete_raid.side_effect = (
            exception.IloLogicalDriveNotFoundError('No logical drive found'))
        self.assertRaisesRegex(
            exception.IloError,
            "No logical drives are found in any controllers. "
            "Nothing to delete.",
            self.sys_inst.delete_raid)

    def test_check_smart_storage_config_ids(self):
        type(self.sys_inst).smart_storage_config_identities = (
            mock.PropertyMock(return_value=None))
        self.assertRaisesRegex(
            exception.IloError,
            "The Redfish controller failed to get the SmartStorageConfig "
            "controller configurations",
            self.sys_inst.check_smart_storage_config_ids)

    @mock.patch.object(system.HPESystem, 'check_smart_storage_config_ids')
    @mock.patch.object(system.HPESystem, '_parse_raid_config_data')
    @mock.patch.object(system.HPESystem,
                       '_get_smart_storage_config_by_controller_model')
    def test_create_raid(self, get_smart_storage_config_model_mock,
                         parse_raid_config_mock,
                         check_smart_storage_config_ids_mock):
        ld1 = {'raid_level': '0', 'is_root_volume': True,
               'size_gb': 150,
               'controller': 'HPE Smart Array P408i-p SR Gen10'}
        ld2 = {'raid_level': '1', 'size_gb': 200,
               'controller': 'HPE Smart Array P408i-p SR Gen10'}
        raid_config = {'logical_disks': [ld1, ld2]}
        parse_data = {'HPE Smart Array P408i-p SR Gen10': [ld1, ld2]}
        parse_raid_config_mock.return_value = parse_data
        check_smart_storage_config_ids_mock.return_value = None
        self.sys_inst.create_raid(raid_config)
        get_smart_storage_config_model_mock.assert_called_once_with(
            'HPE Smart Array P408i-p SR Gen10')
        (get_smart_storage_config_model_mock.return_value.
         create_raid.assert_called_once_with(raid_config))

    @mock.patch.object(system.HPESystem, 'check_smart_storage_config_ids')
    @mock.patch.object(system.HPESystem, '_parse_raid_config_data')
    @mock.patch.object(system.HPESystem,
                       '_get_smart_storage_config_by_controller_model')
    def test_create_raid_controller_not_found(
            self, get_smart_storage_config_model_mock, parse_raid_config_mock,
            check_smart_storage_config_ids_mock):
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller.json', 'r') as f:
            ac_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = [
            ss_json, acc_json, ac_json]
        ld1 = {'raid_level': '1', 'size_gb': 200,
               'controller': 'HPE Gen10 Controller'}
        raid_config = {'logical_disks': [ld1]}
        parse_data = {'HPE Gen10 Controller': [ld1]}
        parse_raid_config_mock.return_value = parse_data
        check_smart_storage_config_ids_mock.return_value = None
        get_smart_storage_config_model_mock.return_value = None
        self.assertRaisesRegex(
            exception.IloError,
            "The Redfish controller failed to create the raid "
            "configuration for one or more controllers with",
            self.sys_inst.create_raid, raid_config)

    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'array_controller_by_location')
    @mock.patch.object(system.HPESystem, 'get_smart_storage_config')
    def test__post_delete_read_raid(
            self, get_smart_storage_config_mock,
            array_controller_by_location_mock):
        config_id = ['/redfish/v1/systems/1/smartstorageconfig/']
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = [ss_json, acc_json]
        type(get_smart_storage_config_mock.return_value).location = 'Slot 0'
        model = 'HPE Smart Array P408i-a SR Gen10'
        type(array_controller_by_location_mock.return_value).model = model
        type(self.sys_inst).smart_storage_config_identities = (
            mock.PropertyMock(return_value=config_id))
        result = {'logical_disks': []}
        (get_smart_storage_config_mock.
         return_value.read_raid.return_value) = result
        self.assertEqual(result, self.sys_inst._post_delete_read_raid())
        get_smart_storage_config_mock.assert_called_once_with(config_id[0])

    @mock.patch.object(system.HPESystem, '_parse_raid_config_data')
    @mock.patch.object(system.HPESystem,
                       '_get_smart_storage_config_by_controller_model')
    def test__post_create_read_raid(
            self, get_ssc_by_controller_model_mock,
            parse_raid_config_data_mock):
        ld1 = {'raid_level': '0', 'is_root_volume': True,
               'size_gb': 150,
               'controller': 'HPE Smart Array P408i-p SR Gen10'}
        raid_config = {'logical_disks': [ld1]}
        parse_data = {'HPE Smart Array P408i-p SR Gen10': [ld1]}
        parse_raid_config_data_mock.return_value = parse_data
        result_ld1 = [{'size_gb': 149,
                       'physical_disks': [u'2I:1:1'],
                       'raid_level': u'0',
                       'controller': 'HPE Smart Array P408i-p SR Gen10',
                       'root_device_hint': {'wwn': u'0x600508B'},
                       'volume_name': u'01E6E63APFJHD'}]
        result = {'logical_disks': result_ld1}
        (get_ssc_by_controller_model_mock.
         return_value.read_raid.return_value) = result
        self.assertEqual(
            result,
            self.sys_inst._post_create_read_raid(raid_config=raid_config))
        get_ssc_by_controller_model_mock.assert_called_once_with(
            ld1['controller'])

    @mock.patch.object(system.HPESystem, '_parse_raid_config_data')
    @mock.patch.object(system.HPESystem,
                       '_get_smart_storage_config_by_controller_model')
    def test__post_create_read_raid_logical_drive_not_found(
            self, get_ssc_by_controller_model_mock,
            parse_raid_config_data_mock):
        ld1 = {'raid_level': '0', 'is_root_volume': True,
               'size_gb': 150,
               'controller': 'HPE Smart Array P408i-p SR Gen10'}
        raid_config = {'logical_disks': [ld1]}
        parse_data = {'HPE Smart Array P408i-p SR Gen10': [ld1]}
        parse_raid_config_data_mock.return_value = parse_data
        get_ssc_by_controller_model_mock.return_value.read_raid.side_effect = (
            exception.IloLogicalDriveNotFoundError('No logical drive found'))
        self.assertRaisesRegex(
            exception.IloError,
            "No logical drives are found in any controllers.",
            self.sys_inst._post_create_read_raid, raid_config)

    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'array_controller_by_location')
    @mock.patch.object(system.HPESystem, 'get_smart_storage_config')
    def test__post_delete_read_raid_failed(
            self, get_smart_storage_config_mock,
            array_controller_by_location_mock):
        config_id = ['/redfish/v1/systems/1/smartstorageconfig/']
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = [ss_json, acc_json]
        model = 'HPE Smart Array P408i-a SR Gen10'
        type(array_controller_by_location_mock.return_value).model = model
        type(self.sys_inst).smart_storage_config_identities = (
            mock.PropertyMock(return_value=config_id))
        get_smart_storage_config_mock.return_value.read_raid.side_effect = (
            sushy.exceptions.SushyError)
        self.assertRaisesRegex(
            exception.IloError,
            "The Redfish controller failed to read the "
            "raid configuration in one or more controllers with Error:",
            self.sys_inst._post_delete_read_raid)

    @mock.patch.object(system.HPESystem, 'check_smart_storage_config_ids')
    @mock.patch.object(system.HPESystem, '_parse_raid_config_data')
    @mock.patch.object(system.HPESystem,
                       '_get_smart_storage_config_by_controller_model')
    def test_create_raid_failed(self, get_smart_storage_config_model_mock,
                                parse_raid_config_mock,
                                check_smart_storage_config_ids_mock):
        ld1 = {'raid_level': '0', 'is_root_volume': True,
               'size_gb': 150,
               'controller': 'HPE Smart Array P408i-p SR Gen10'}
        ld2 = {'raid_level': '1', 'size_gb': 200,
               'controller': 'HPE Smart Array P408i-p SR Gen10'}
        raid_config = {'logical_disks': [ld1, ld2]}
        parse_data = {'HPE Smart Array P408i-p SR Gen10': [ld1, ld2]}
        check_smart_storage_config_ids_mock.return_value = None
        parse_raid_config_mock.return_value = parse_data
        (get_smart_storage_config_model_mock.
         return_value.create_raid.side_effect) = sushy.exceptions.SushyError
        self.assertRaisesRegex(
            exception.IloError,
            "The Redfish controller failed to create the "
            "raid configuration for one or more controllers with Error:",
            self.sys_inst.create_raid, raid_config)

    def test__parse_raid_config_data(self):
        ld1 = {'raid_level': '0', 'is_root_volume': True,
               'size_gb': 150,
               'controller': 'HPE Smart Array P408i-a SR Gen10'}
        ld2 = {'raid_level': '1', 'size_gb': 200,
               'controller': 'HPE Smart Array P408i-a SR Gen10'}
        raid_config = {'logical_disks': [ld1, ld2]}
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller.json', 'r') as f:
            ac_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = [
            ss_json, acc_json, ac_json]
        expected = {'HPE Smart Array P408i-a SR Gen10': [ld1, ld2]}
        self.assertEqual(expected,
                         self.sys_inst._parse_raid_config_data(raid_config))

    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'array_controller_by_model')
    @mock.patch.object(system.HPESystem, 'get_smart_storage_config')
    def test__get_smart_storage_config_by_controller_model(
            self, get_smart_storage_config_mock,
            array_controller_by_model_mock):
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = [ss_json, acc_json]
        type(array_controller_by_model_mock.return_value).location = 'Slot 0'
        type(get_smart_storage_config_mock.return_value).location = 'Slot 0'
        self.assertEqual(
            'Slot 0',
            self.sys_inst._get_smart_storage_config_by_controller_model(
                'HPE Smart Array P408i-a SR Gen10').location)

    @mock.patch.object(system.HPESystem, '_parse_raid_config_data')
    @mock.patch.object(system.HPESystem,
                       '_get_smart_storage_config_by_controller_model')
    def test__post_create_read_raid_failed_with_raid_config(
            self, get_ssc_by_controller_model_mock,
            parse_raid_config_data_mock):
        ld1 = {'raid_level': '0', 'is_root_volume': True,
               'size_gb': 150,
               'controller': 'HPE Smart Array P408i-p SR Gen10'}
        raid_config = {'logical_disks': [ld1]}
        parse_data = {'HPE Smart Array P408i-p SR Gen10': [ld1]}
        parse_raid_config_data_mock.return_value = parse_data
        (get_ssc_by_controller_model_mock.
         return_value.read_raid.side_effect) = sushy.exceptions.SushyError
        self.assertRaisesRegex(
            exception.IloError,
            "The Redfish controller failed to read the "
            "raid configuration in one or more controllers with Error:",
            self.sys_inst._post_create_read_raid, raid_config=raid_config)

    @mock.patch.object(system.HPESystem, '_post_create_read_raid')
    @mock.patch.object(system.HPESystem, 'check_smart_storage_config_ids')
    def test_read_raid_post_create(
            self, check_smart_storage_config_ids_mock,
            post_create_read_raid_mock):
        check_smart_storage_config_ids_mock.return_value = None
        ld1 = {'raid_level': '0', 'is_root_volume': True,
               'size_gb': 150,
               'controller': 'HPE Smart Array P408i-p SR Gen10'}
        raid_config = {'logical_disks': [ld1]}
        result_ld1 = [{'size_gb': 149,
                       'physical_disks': [u'2I:1:1'],
                       'raid_level': u'0',
                       'controller': 'HPE Smart Array P408i-p SR Gen10',
                       'root_device_hint': {'wwn': u'0x600508B'},
                       'volume_name': u'01E6E63APFJHD'}]
        result = {'logical_disks': result_ld1}
        post_create_read_raid_mock.return_value = result
        self.assertEqual(
            result, self.sys_inst.read_raid(raid_config=raid_config))

    @mock.patch.object(system.HPESystem, '_post_delete_read_raid')
    @mock.patch.object(system.HPESystem, 'check_smart_storage_config_ids')
    def test_read_raid_post_delete(
            self, check_smart_storage_config_ids_mock,
            post_delete_read_raid_mock):
        check_smart_storage_config_ids_mock.return_value = None
        result = {'logical_disks': []}
        post_delete_read_raid_mock.return_value = result
        self.assertEqual(
            result, self.sys_inst.read_raid())

    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'get_all_controllers_model')
    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'array_controller_by_model')
    def test_has_disk_erase_completed_true(
            self, array_controller_by_model_mock,
            get_all_controllers_model_mock):
        get_all_controllers_model_mock.return_value = [
            'HPE Smart Array P408i-p SR Gen10']
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = [ss_json, acc_json]
        type(array_controller_by_model_mock.
             return_value.physical_drives).has_disk_erase_completed = True
        self.assertEqual(True, self.sys_inst.has_disk_erase_completed())

    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'get_all_controllers_model')
    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'array_controller_by_model')
    def test_has_disk_erase_completed_false(
            self, array_controller_by_model_mock,
            get_all_controllers_model_mock):
        get_all_controllers_model_mock.return_value = [
            'HPE Smart Array P408i-p SR Gen10']
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = [ss_json, acc_json]
        type(array_controller_by_model_mock.
             return_value.physical_drives).has_disk_erase_completed = False
        self.assertEqual(False, self.sys_inst.has_disk_erase_completed())

    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'get_all_controllers_model')
    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'array_controller_by_model')
    def test_has_disk_erase_completed_failed(
            self, array_controller_by_model_mock,
            get_all_controllers_model_mock):
        get_all_controllers_model_mock.return_value = [
            'HPE Smart Array P408i-p SR Gen10']
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        (self.conn.get.return_value.
         json.side_effect) = [ss_json, sushy.exceptions.SushyError]
        self.assertRaisesRegex(
            exception.IloError,
            "The Redfish controller failed to get the status of sanitize disk "
            "erase. Error:",
            self.sys_inst.has_disk_erase_completed)

    @mock.patch.object(system.HPESystem,
                       '_get_hpe_one_button_secure_erase_action_element')
    def test_do_one_button_secure_erase(
            self, secure_erase_action_mock):
        target_uri = (
            '/redfish/v1/Systems/1/Actions/Oem/Hpe/'
            '#HpeComputerSystemExt.SecureSystemErase')
        data = {
            "SystemROMAndiLOErase": True,
            "UserDataErase": True}
        type(secure_erase_action_mock.return_value).target_uri = target_uri
        self.sys_inst.do_one_button_secure_erase()
        self.sys_inst._conn.post.assert_called_once_with(target_uri, data=data)

    @mock.patch.object(system.HPESystem,
                       '_get_hpe_one_button_secure_erase_action_element')
    def test_do_one_button_secure_erase_failed(
            self, secure_erase_action_mock):
        target_uri = (
            '/redfish/v1/Systems/1/Actions/Oem/Hpe/'
            '#HpeComputerSystemExt.SecureSystemErase')
        type(secure_erase_action_mock.return_value).target_uri = target_uri
        self.sys_inst._conn.post.side_effect = sushy.exceptions.SushyError
        self.assertRaisesRegex(
            exception.IloError,
            "The Redfish controller failed to perform one button "
            "secure erase operation on the hardware. Error:",
            self.sys_inst.do_one_button_secure_erase)

    @mock.patch.object(system.HPESystem,
                       '_get_drives_has_raid')
    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'get_all_controllers_model')
    @mock.patch.object(system.HPESystem,
                       '_get_smart_storage_config_by_controller_model')
    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'array_controller_by_model')
    def test_do_disk_erase_hdd(
            self, array_controller_by_model_mock,
            get_ssc_by_controller_model_mock,
            get_all_controllers_model_mock,
            drives_raid_mock):
        get_all_controllers_model_mock.return_value = [
            'HPE Smart Array P408i-p SR Gen10']
        drives_raid_mock.return_value = []
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = [ss_json, acc_json]
        (array_controller_by_model_mock.return_value.physical_drives.
         get_all_hdd_drives_locations.return_value) = ['2I:1:1']
        self.sys_inst.do_disk_erase('HDD', None)
        get_ssc_by_controller_model_mock.assert_called_once_with(
            'HPE Smart Array P408i-p SR Gen10')
        (get_ssc_by_controller_model_mock.return_value.
         disk_erase.assert_called_once_with(['2I:1:1'], 'HDD', None))

    @mock.patch.object(system.HPESystem,
                       '_get_drives_has_raid')
    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'get_all_controllers_model')
    @mock.patch.object(system.HPESystem,
                       '_get_smart_storage_config_by_controller_model')
    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'array_controller_by_model')
    def test_do_disk_erase_ssd(
            self, array_controller_by_model_mock,
            get_ssc_by_controller_model_mock,
            get_all_controllers_model_mock,
            drives_raid_mock):
        drives_raid_mock.return_value = []
        get_all_controllers_model_mock.return_value = [
            'HPE Smart Array P408i-p SR Gen10']
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = [ss_json, acc_json]
        (array_controller_by_model_mock.return_value.physical_drives.
         get_all_ssd_drives_locations.return_value) = ['2I:1:1']
        self.sys_inst.do_disk_erase('SSD', None)
        get_ssc_by_controller_model_mock.assert_called_once_with(
            'HPE Smart Array P408i-p SR Gen10')
        (get_ssc_by_controller_model_mock.return_value.
         disk_erase.assert_called_once_with(['2I:1:1'], 'SSD', None))

    @mock.patch.object(system.LOG, 'warn', autospec=True)
    @mock.patch.object(system.HPESystem,
                       '_get_disk_properties_by_drive_location')
    @mock.patch.object(system.HPESystem,
                       '_get_drives_has_raid')
    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'get_all_controllers_model')
    @mock.patch.object(system.HPESystem,
                       '_get_smart_storage_config_by_controller_model')
    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'array_controller_by_model')
    def test_do_disk_erase_with_raid(
            self, array_controller_by_model_mock,
            get_ssc_by_controller_model_mock,
            get_all_controllers_model_mock,
            drives_raid_mock, get_disk_prop_mock,
            system_log_mock):
        get_all_controllers_model_mock.return_value = [
            'HPE Smart Array P408i-p SR Gen10']
        drives_raid_mock.return_value = ['2I:1:2']
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = [ss_json, acc_json]
        (array_controller_by_model_mock.return_value.physical_drives.
         get_all_hdd_drives_locations.return_value) = ['2I:1:1', '2I:1:2']
        get_disk_prop_mock.return_value = {
            'Serial number': 'KWGER73R',
            'Size(GB)': 600,
            'Media type': 'HDD',
            'Location': '2I:1:2'}
        self.sys_inst.do_disk_erase('HDD', None)
        get_ssc_by_controller_model_mock.assert_called_once_with(
            'HPE Smart Array P408i-p SR Gen10')
        (get_ssc_by_controller_model_mock.return_value.
         disk_erase.assert_called_once_with(['2I:1:1'], 'HDD', None))
        disk_prop = {'Serial number': 'KWGER73R',
                     'Size(GB)': 600,
                     'Media type': 'HDD',
                     'Location': '2I:1:2'}
        system_log_mock.assert_called_once_with(
            "Skipping disk erase of %(disk_list)s "
            "with logical volumes on them."
            % {'disk_list': [disk_prop]})

    @mock.patch.object(system.HPESystem,
                       '_get_drives_has_raid')
    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'get_all_controllers_model')
    @mock.patch.object(system.HPESystem,
                       '_get_smart_storage_config_by_controller_model')
    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'array_controller_by_model')
    @mock.patch.object(system.LOG, 'warn', autospec=True)
    def test_do_disk_erase_with_S_and_P_series_controller(
            self, system_log_mock, array_controller_by_model_mock,
            get_ssc_by_controller_model_mock, get_all_controllers_model_mock,
            drives_raid_mock):
        drives_raid_mock.return_value = []
        get_all_controllers_model_mock.return_value = [
            'HPE Smart Array S100i SR Gen10',
            'HPE Smart Array P408i-p SR Gen10']
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = [ss_json, acc_json]
        (array_controller_by_model_mock.return_value.physical_drives.
         get_all_ssd_drives_locations.return_value) = ['2I:1:1']
        self.sys_inst.do_disk_erase('SSD', None)
        get_ssc_by_controller_model_mock.assert_called_once_with(
            'HPE Smart Array P408i-p SR Gen10')
        (get_ssc_by_controller_model_mock.return_value.
         disk_erase.assert_called_once_with(['2I:1:1'], 'SSD', None))
        system_log_mock.assert_called_once_with(
            "Smart array controller: HPE Smart Array S100i SR Gen10, doesn't "
            "support sanitize disk erase. All the disks of the controller are "
            "ignored.")

    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'get_all_controllers_model')
    def test_do_disk_erase_failed(
            self, get_all_controllers_model_mock):
        get_all_controllers_model_mock.return_value = [
            'HPE Smart Array P408i-p SR Gen10']
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        (self.conn.get.return_value.
         json.side_effect) = [ss_json, acc_json, sushy.exceptions.SushyError]
        self.assertRaisesRegex(
            exception.IloError,
            "The Redfish controller failed to perform the sanitize disk erase "
            "on smart storage controller: HPE Smart Array P408i-p SR Gen10, "
            "on disk_type: SSD with error:",
            self.sys_inst.do_disk_erase, 'SSD', None)

    @mock.patch.object(system.HPESystem, 'get_smart_storage_config')
    def test__get_drives_has_raid(
            self, get_smart_storage_config_mock):
        config_id = ['/redfish/v1/systems/1/smartstorageconfig/']
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
            self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = ss_json
        type(self.sys_inst).smart_storage_config_identities = (
            mock.PropertyMock(return_value=config_id))
        (get_smart_storage_config_mock.
         return_value.get_drives_has_raid.return_value) = ["2I:1:2", "2I:1:1"]
        result = self.sys_inst._get_drives_has_raid()
        self.assertEqual(result, ["2I:1:2", "2I:1:1"])
        get_smart_storage_config_mock.assert_called_once_with(config_id[0])

    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'get_all_controllers_model')
    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'array_controller_by_model')
    def test__get_disk_properties_by_drive_location(
            self, array_controller_by_model_mock,
            get_all_controllers_model_mock):
        get_all_controllers_model_mock.return_value = [
            'HPE Smart Array P408i-p SR Gen10']
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = [ss_json, acc_json]
        prop = {
            'Serial number': 'KWGER73R',
            'Size(GB)': 600,
            'Media type': 'HDD',
            'Location': '2I:1:2'}
        (array_controller_by_model_mock.return_value.physical_drives.
         get_disk_properties_by_drive_location.return_value) = prop
        result = self.sys_inst._get_disk_properties_by_drive_location(
            '2I:1:1')
        self.assertEqual(result, prop)

    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'get_all_controllers_model')
    @mock.patch.object(array_controller.HPEArrayControllerCollection,
                       'array_controller_by_model')
    def test_get_disk_types(
            self, array_controller_by_model_mock,
            get_all_controllers_model_mock):
        get_all_controllers_model_mock.return_value = [
            'HPE Smart Array P408i-p SR Gen10']
        with open('proliantutils/tests/redfish/'
                  'json_samples/smart_storage.json', 'r') as f:
            ss_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/array_controller_collection.json', 'r') as f:
            acc_json = json.loads(f.read())
        self.conn.get.return_value.json.reset_mock()
        self.conn.get.return_value.json.side_effect = [ss_json, acc_json]
        (array_controller_by_model_mock.return_value.physical_drives.
         has_hdd.return_value) = True
        (array_controller_by_model_mock.return_value.physical_drives.
         has_ssd.return_value) = False
        types = ['HDD', 'SSD']
        self.assertEqual(list(set(types)), self.sys_inst.get_disk_types())
        array_controller_by_model_mock.assert_called_once_with(
            'HPE Smart Array P408i-p SR Gen10')

    @mock.patch.object(ethernet_interface.EthernetInterfaceCollection,
                       'get_uefi_device_path_by_mac')
    def test_get_nic_association_name_by_mac(self, uefi_device_path_mock):
        with open('proliantutils/tests/redfish/'
                  'json_samples/bios.json', 'r') as f:
            bios_json = json.loads(f.read())
        with open('proliantutils/tests/redfish/'
                  'json_samples/bios_mappings.json', 'r') as f:
            bios_mappings_json = json.loads(f.read())
        path = ('proliantutils/tests/redfish/json_samples/'
                'ethernet_interface_collection.json')
        with open(path, 'r') as f:
            eth_coll = json.loads(f.read())
        self.conn.get.return_value.json.side_effect = [
            bios_json['Default'], bios_mappings_json['Default'],
            eth_coll]
        (uefi_device_path_mock.
         return_value) = 'PciRoot(0x2)/Pci(0x0,0x0)/Pci(0x0,0x2)'
        result = self.sys_inst.get_nic_association_name_by_mac(
            '12:44:6A:3B:04:11')
        self.assertEqual(result, 'NicBoot1')

    @mock.patch.object(ethernet_interface.EthernetInterfaceCollection,
                       'get_all_macs')
    def test_validate_macs(self, get_all_macs_mock):
        path = ('proliantutils/tests/redfish/json_samples/'
                'ethernet_interface_collection.json')
        with open(path, 'r') as f:
            eth_coll = json.loads(f.read())
        self.conn.get.return_value.json.side_effect = [eth_coll]
        get_all_macs_mock.return_value = [
            '12:44:6a:3b:04:11', '13:44:6a:3b:04:13']
        result = self.sys_inst.validate_macs(['12:44:6a:3b:04:11'])
        self.assertEqual(result, None)

    @mock.patch.object(ethernet_interface.EthernetInterfaceCollection,
                       'get_all_macs')
    def test_validate_macs_failed(self, get_all_macs_mock):
        path = ('proliantutils/tests/redfish/json_samples/'
                'ethernet_interface_collection.json')
        with open(path, 'r') as f:
            eth_coll = json.loads(f.read())
        self.conn.get.return_value.json.side_effect = [eth_coll]
        get_all_macs_mock.return_value = [
            '12:44:6a:3b:04:11', '13:44:6a:3b:04:13']
        self.assertRaisesRegex(
            exception.InvalidInputError,
            r"Given macs: \['14:23:AD:3B:4C:78'\] not found in the system",
            self.sys_inst.validate_macs,
            ['12:44:6a:3b:04:11', '14:23:AD:3B:4C:78'])



#
# PySNMP MIB module RFC1215-MIB (http://pysnmp.sf.net)
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( egpNeighAddr, ) = mibBuilder.importSymbols("RFC1213-MIB", "egpNeighAddr")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, MibIdentifier, mib_2, IpAddress, TimeTicks, Counter64, Unsigned32, iso, Gauge32, ModuleIdentity, ObjectIdentity, Bits, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "NotificationType", "MibIdentifier", "mib-2", "IpAddress", "TimeTicks", "Counter64", "Unsigned32", "iso", "Gauge32", "ModuleIdentity", "ObjectIdentity", "Bits", "Counter32")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
snmp = MibIdentifier((1, 3, 6, 1, 2, 1, 11))
coldStart = NotificationType((1, 3, 6, 1, 2, 1, 11) + (0,0)).setObjects(*())
warmStart = NotificationType((1, 3, 6, 1, 2, 1, 11) + (0,1)).setObjects(*())
linkDown = NotificationType((1, 3, 6, 1, 2, 1, 11) + (0,2)).setObjects(*(("RFC1215-MIB", "ifIndex"),))
linkUp = NotificationType((1, 3, 6, 1, 2, 1, 11) + (0,3)).setObjects(*(("RFC1215-MIB", "ifIndex"),))
authenticationFailure = NotificationType((1, 3, 6, 1, 2, 1, 11) + (0,4)).setObjects(*())
egpNeighborLoss = NotificationType((1, 3, 6, 1, 2, 1, 11) + (0,5)).setObjects(*(("RFC1215-MIB", "egpNeighAddr"),))
mibBuilder.exportSymbols("RFC1215-MIB", linkDown=linkDown, authenticationFailure=authenticationFailure, warmStart=warmStart, egpNeighborLoss=egpNeighborLoss, snmp=snmp, linkUp=linkUp, coldStart=coldStart)



# Copyright 2015 Hewlett-Packard Development Company, L.P.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from proliantutils import exception
from proliantutils.hpssa import constants

FILTER_CRITERIA = ['disk_type', 'interface_type', 'model', 'firmware']


def _get_criteria_matching_disks(logical_disk, physical_drives):
    """Finds the physical drives matching the criteria of logical disk.

    This method finds the physical drives matching the criteria
    of the logical disk passed.

    :param logical_disk: The logical disk dictionary from raid config
    :param physical_drives: The physical drives to consider.
    :returns: A list of physical drives which match the criteria
    """
    matching_physical_drives = []
    criteria_to_consider = [x for x in FILTER_CRITERIA
                            if x in logical_disk]

    for physical_drive_object in physical_drives:
        for criteria in criteria_to_consider:
            logical_drive_value = logical_disk.get(criteria)
            physical_drive_value = getattr(physical_drive_object, criteria)
            if logical_drive_value != physical_drive_value:
                break
        else:
            matching_physical_drives.append(physical_drive_object)

    return matching_physical_drives


def allocate_disks(logical_disk, server, raid_config):
    """Allocate physical disks to a logical disk.

    This method allocated physical disks to a logical
    disk based on the current state of the server and
    criteria mentioned in the logical disk.

    :param logical_disk: a dictionary of a logical disk
        from the RAID configuration input to the module.
    :param server: An objects.Server object
    :param raid_config: The target RAID configuration requested.
    :raises: PhysicalDisksNotFoundError, if cannot find
        physical disks for the request.
    """
    size_gb = logical_disk['size_gb']
    raid_level = logical_disk['raid_level']
    number_of_physical_disks = logical_disk.get(
        'number_of_physical_disks', constants.RAID_LEVEL_MIN_DISKS[raid_level])
    share_physical_disks = logical_disk.get('share_physical_disks', False)

    # Try to create a new independent array for this request.
    for controller in server.controllers:
        physical_drives = controller.unassigned_physical_drives
        physical_drives = _get_criteria_matching_disks(logical_disk,
                                                       physical_drives)

        if size_gb != "MAX":
            # If we want to allocate for a logical disk for which size_gb is
            # mentioned, we take the smallest physical drives which is required
            # to match the criteria.
            reverse_sort = False
            physical_drives = [x for x in physical_drives
                               if x.size_gb >= size_gb]
        else:
            # If we want to allocate for a logical disk for which size_gb is
            # MAX, we take the largest physical drives available.
            reverse_sort = True

        if len(physical_drives) >= number_of_physical_disks:
            selected_drives = sorted(physical_drives, key=lambda x: x.size_gb,
                                     reverse=reverse_sort)
            selected_drive_ids = [x.id for x in selected_drives]
            logical_disk['controller'] = controller.id
            physical_disks = selected_drive_ids[:number_of_physical_disks]
            logical_disk['physical_disks'] = physical_disks
            return

    # We didn't find physical disks to create an independent array.
    # Check if we can get some shared arrays.
    if share_physical_disks:
        sharable_disk_wwns = []
        for sharable_logical_disk in raid_config['logical_disks']:
            if (sharable_logical_disk.get('share_physical_disks', False)
                    and 'root_device_hint' in sharable_logical_disk):
                wwn = sharable_logical_disk['root_device_hint']['wwn']
                sharable_disk_wwns.append(wwn)

        for controller in server.controllers:
            sharable_arrays = [x for x in controller.raid_arrays if
                               x.logical_drives[0].wwn in sharable_disk_wwns]

            for array in sharable_arrays:

                # Check if criterias for the logical disk match the ones with
                # physical disks in the raid array.
                criteria_matched_disks = _get_criteria_matching_disks(
                    logical_disk, array.physical_drives)

                # Check if all disks in the array don't match the criteria
                if len(criteria_matched_disks) != len(array.physical_drives):
                    continue

                # Check if raid array can accomodate the logical disk.
                if array.can_accomodate(logical_disk):
                    logical_disk['controller'] = controller.id
                    logical_disk['array'] = array.id
                    return

    # We check both options and couldn't get any physical disks.
    raise exception.PhysicalDisksNotFoundError(size_gb=size_gb,
                                               raid_level=raid_level)



# Copyright 2017 Hewlett Packard Enterprise Development LP
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from sushy.resources import base
from sushy import utils as sushy_utils

from proliantutils.redfish import utils


class TLSConfig(base.ResourceBase):
    """Class that represents the TLS Configuration.

    This class extends the functionality of base resource class
    from sushy.
    """

    tls_certificates = base.Field('Certificates')
    """The certificates currently configured"""

    @property
    @sushy_utils.cache_it
    def tls_config_settings(self):
        """Property to provide reference to TLS configuration settings instance

        It is calculated once when the first time it is queried. On refresh,
        this property gets reset.
        """
        return TLSConfigSettings(
            self._conn,
            utils.get_subresource_path_by(
                self, ["@Redfish.Settings", "SettingsObject"]),
            redfish_version=self.redfish_version)


class TLSConfigSettings(base.ResourceBase):
    """Class that represents the TLS configuration settings.

    This class extends the functionality of base resource class
    from sushy.
    """

    def add_tls_certificate(self, cert_data):
        """Update tls certificate

        :param data: default tls certs data
        """
        self._conn.put(self.path, data=cert_data)

    def remove_tls_certificate(self, cert_data):
        """Update tls certificate

        :param data: default tls certs data
        """
        self._conn.put(self.path, data=cert_data)
